/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.actions;

import de.uni_due.inf.ti.raven.data.Data;
import de.uni_due.inf.ti.raven.data.Repository;

/**
 * Handles addition of a graph to the repository.
 * @author Christoph Blume
 * @version $Revision: 1.4 $
 *
 */
public class AddToRepositoryAction extends ComputationAction<Boolean> {
	
	private String name;
	private Data data;
	private boolean result;

	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates a new {@code Action} to add a Data-object {@code data} with the name {@code name} to 
	 * the repository. 
	 * @param name the name of the graph
	 * @param data the graph
	 */
	public AddToRepositoryAction(String name, Data data) {
		this.name = name;
		this.data = data;
	}

	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	@Override
	public void execute() {
		//Add graph to the repository
		result = Repository.getRepository().put(name, data);
	}

	@Override
	public Boolean getResult() {
		return result;
	}

	@Override
	public void addComputationListener(ComputationListener l) {
		// Do nothing since there is nothing which is computed
	}

	@Override
	public void removeComputationListener(ComputationListener l) {
		// Do nothing since there is nothing which is computed
	}

	@Override
	public void cancelComputation() {
		// Do nothing (as long as the computation can not be cancelled reasonably
	}

}
