/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.actions;

import java.io.IOException;

/**
 * The {@code IOAction} class is extended by classes which perform some kind of I/O. Classes 
 * implementing this interface have to guarantee that occurring {@link IOException} are handled 
 * suitable. However, the implementing class has to provide information whether an exception has 
 * occurred and if so, what kind of exception.
 * @author Christoph Blume
 *
 */
public interface IOAction extends Action {
	
	/**
	 * Returns {@code true} if an exception has been occurred during 
	 * the execution of this action.
	 * @return {@code true} if an exception has been occurred, {@code false}
	 * otherwise
	 */
	public boolean hasExceptionOccured();
	
	/**
	 * Returns the exception which has been occurred if existing.
	 * @return the exception or {@code null} if no exception has been occurred
	 */
	public Exception getException();
	
}
