/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.actions;

import de.uni_due.inf.ti.raven.data.Graph;
import de.uni_due.inf.ti.raven.data.bdd.RavenBDD;
import de.uni_due.inf.ti.raven.io.DotPrinter;
import de.uni_due.inf.ti.raven.messages.RavenExceptionMessages;

/**
 * Handles printout of BDDs and graphs in DOT syntax.
 * @author Christoph Blume
 * @version $Revision: 1.12 $
 *
 */
public class PrintDotAction implements Action {

	private DotPrinter printer;
	private Graph graph;
	private RavenBDD bdd;

	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/

	/**
	 * Creates an action which prints a graph to a given printer.
	 * @param printer the printer to be used
	 * @param graph the graph to be printed
	 */
	public PrintDotAction(DotPrinter printer, Graph graph) {
		if(printer==null) {
			throw new NullPointerException(
					RavenExceptionMessages.PRINTER_MUST_NOT_BE_NULL_EXCEPTION);
		}
		if(graph==null) {
			throw new NullPointerException(
					RavenExceptionMessages.GRAPH_MUST_NOT_BE_NULL_EXCEPTION);
		}

		this.printer = printer;
		this.graph = graph;
	}

	/**
	 * Creates an action which prints a BDD to a given printer.
	 * @param printer the printer to be used
	 * @param bdd the BDD to be printed
	 */
	public PrintDotAction(DotPrinter printer, RavenBDD bdd) {
		if(printer==null) {
			throw new NullPointerException(
					RavenExceptionMessages.PRINTER_MUST_NOT_BE_NULL_EXCEPTION);
		}
		if(bdd==null) {
			throw new NullPointerException(
					RavenExceptionMessages.BDD_MUST_NOT_BE_NULL_EXCEPTION);
		}

		this.printer = printer;
		this.bdd = bdd;
	}

	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/

	@Override
	public void execute() {
		if(graph!=null) {
			printer.print(graph);
		}
		else if(bdd!=null) {
			printer.print(bdd);
		}
	}

}
