/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.actions;

import java.util.Set;

import de.uni_due.inf.ti.raven.data.Operation;
import de.uni_due.inf.ti.raven.data.Repository;
import de.uni_due.inf.ti.raven.data.Signature;
import de.uni_due.inf.ti.raven.messages.RavenExceptionMessages;

/**
 * Handles creation of a new signature.
 * @author Christoph Blume
 * @version $Revision: 1.14 $
 *
 */
public class SignatureAction implements Action {

	private String name;
	private Set<Operation> operationList;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates a new {@code Action} to define a new signature with the name {@code name} and all 
	 * {@code Operation} objects contained in the set {@code operationSet}. Creates an action 
	 * which defines a new signature.
	 * @param name the name of the signature
	 * @param operationSet the set of operations of the new signature
	 * 
	 *  @see Signature
	 *  @see Operation
	 */	
	public SignatureAction(String name, Set<Operation> operationSet) {
		if(name==null) {
			throw new NullPointerException(
					RavenExceptionMessages.NAME_MUST_NOT_BE_NULL_EXCEPTION);
		}
		if(name.isEmpty()) {
			throw new IllegalArgumentException(
					RavenExceptionMessages.NAME_MUST_NOT_BE_EMPTY_EXCEPTION);
		}
		if(operationSet==null) {
			throw new NullPointerException(
					RavenExceptionMessages.SET_OF_LETTERS_MUST_NOT_BE_NULL_EXCEPTION);
		}
		
		this.name = name;
		this.operationList = operationSet;
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/

	@Override
	public void execute() {
		//Create Signature
		Signature signature = new Signature();
		for(Operation operation: operationList) {
			signature.add(operation);
		}
		
		//Add signature to the repository
		Repository.getRepository().put(name, signature);
	}

}
