/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.actions;

import java.util.logging.Logger;

import de.uni_due.inf.ti.raven.data.bdd.RavenBDD;

/**
 * Handles computation of the simulation relation for automata.
 * @author Christoph Blume
 * @version $Revision: 1.4 $
 *
 */
public class SimulationCheckingAction extends ComputationAction<Boolean> {

	private RavenBDD simulation; 
	private RavenBDD firstSet;
	private RavenBDD secondSet;
	private Logger logger;

	private Boolean result;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates a new {@code Action} to check for the automaton {@code automaton} whether the  
	 * state set {@code firstSet} is simulated by the state set {@code secondSet}.
	 * @param simulation the simulation which is used for the simulation check
	 * @param firstSet the state set which should be simulated by the second set
	 * @param secondSet the state set which should simulate the first set
	 */
	public SimulationCheckingAction(RavenBDD simulation, RavenBDD firstSet, RavenBDD secondSet) {
		this.simulation = simulation;
		this.firstSet = firstSet;
		this.secondSet = secondSet;

		logger = Logger.getLogger(getClass().getName());
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	@Override
	public void execute() {
		//Notify that the computation has been started
		fireComputationStarted();
		
		logger.info("Check simulation relation");
		simulation = simulation.and(firstSet.clone());
		simulation = simulation.and(secondSet.clone());	
		result = !simulation.isZero();

		//Notify that the computation has been finished
		fireComputationFinished();
	}
	
	@Override
	public Boolean getResult() {
		return result;
	}

	@Override
	public void cancelComputation() {
		// Do nothing (as long as the computation can not be cancelled reasonably
	}

}
