/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.algorithms;

import de.uni_due.inf.ti.raven.actions.ComputationListener;

/**
 * The root interface in the <i>algorithm hierarchy</i>.
 * @author Christoph Blume
 * @version $Revision: 1.16 $
 *
 */
public interface Algorithm {
	
	/**
	 * Search Types for different algorithm, e.g. the antichain-based algorithms
	 * @author Christoph Blume
	 *
	 */
	public enum SearchType {
		/** The forward search type */
		forward,

		/** The backward search type */
		backward
	}
	
	/**
	 * Ordering Types for different algorithm, e.g. the simulation-antichain-based algorithms
	 * @author Christoph Blume
	 * 
	 */
	public enum OrderingType {
		/** Identity Relation order */
		identityRelation,

		/** Forward Simulation preorder */
		forwardSimulation,
		
		/** Backward Simulation preorder */
		backwardSimulation
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Adds the Computation Listener {@code l} to this algorithm.
	 * @param l the listener to receive computation events
	 */
	public void addComputationListener(ComputationListener l);

	/**
	 * Removes the Computation Listener {@code l} from this algorithm.
	 * @param l the listener to be removed
	 */
	public void removeComputationListener(ComputationListener l);
	
	/**
	 * Cancels the computation of this algorithm.
	 */
	public void cancelComputation();
	
}
