/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.algorithms;

import de.uni_due.inf.ti.raven.data.Graph;
import de.uni_due.inf.ti.raven.data.GraphDecomposition;

/**
 * The algorithm interface for the computation of graph decompositions of a given graph. 
 * Each class which implements an algorithm for graph decompositions must implement this 
 * interface.
 * @author Christoph Blume, Laura Steinert
 * @version $Revision: 1.16 $
 *
 */
public interface GraphDecompositionAlgorithm extends Algorithm {
	
	/**
	 * An enumeration of implementations of this algorithm. 
	 * @author Christoph Blume, Laura Steinert
	 *
	 */
	public enum Implementations {
		/** The All Start Lexicographic Breadth-First-Search Implementation */
		ALL_START_LEX_BFS,
		
		/** The Greedy Degree Implementation */
		GREEDY_DEGREE,
		
		/** The Greedy Fill-In Implementation */
		GREEDY_FILL_IN,
		
		/** The Lexicographic Breadth-First-Search Implementation */
		LEX_BFS;
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/

	/**
	 * Returns a graph decomposition of the graph {@code graph}.
	 * @param graph the graph to be decomposed
	 * @return the resulting graph decomposition
	 */
	public GraphDecomposition decompose(Graph graph);

}
