/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.algorithms;

import nl.uu.cs.treewidth.algorithm.AllStartLexBFS;

/**
 * This class implements the All-Start Lex-BFS decomposition algorithm. The algorithm is based 
 * on the Lexicographic Breadth First Search Algorithm and the work of Klaus Simon. More details 
 * about the algorithms can be found in "A note on lexicographic breadth first search for chordal 
 * graphs" <a href="http://dx.doi.org/10.1016/0020-0190(95)00024-7">Science Direct</a>. 
 * @author Christoph Blume
 * @version $Revision: 1.7 $
 *
 */
public class LibTWAllStartLexBFSAlgorithm extends LibTWAlgorithm {
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/

	/**
	 * Creates a new instance of the All Start Lex BFS decomposition algorithm.
	 */	
	public LibTWAllStartLexBFSAlgorithm() {
		super(new AllStartLexBFS<>());
	}

}
