/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.algorithms;

import de.uni_due.inf.ti.raven.data.CospanCounterExample;
import de.uni_due.inf.ti.raven.data.automata.Automaton;

/**
 * The algorithm interface for solving the universality problem. Each class which implements 
 * an universality check must implement this interface.
 * @author Christoph Blume
 * @version $Revision: 1.18 $
 *
 */
public interface UniversalityAlgorithm extends Algorithm {

	/**
	 * An enumeration of implementations of this algorithm. 
	 * @author Christoph Blume
	 *
	 */
	public enum Implementations {
		/** Antichain-based universality checking algorithm */
		AntichainUniversality,
		
		/** Simulation-Antichain-based universality checking algorithm */
		SimulationAntichainUniversality
	}
	
	/** Universality Iteration Step Counter String Literal */
	public static final String UNIVERSALITY_ITERATION_STEP = "[universality] Iteration step: ";
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Returns {@code true} if and only if the automaton {@code automaton} is universal.
	 * @param automaton the automaton to be checked
	 * @return {@code true} if the automaton is universal, {@code false} otherwise
	 */
	public boolean isUniversal(Automaton automaton);
	
	/**
	 * Returns the counter example, if the language of the automaton is not 
	 * universal and {@code null} otherwise
	 * @return the counter example (if the universality check failed) or {@code null}
	 * otherwise
	 */
	public CospanCounterExample getCounterExample();
	
}
