/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.cli;

import java.io.File;

import de.uni_due.inf.ti.raven.cli.Console.Environment;
import de.uni_due.inf.ti.raven.data.Operation;
import de.uni_due.inf.ti.raven.main.RavenMain;

/**
 * Console command to handle the addition of operations in decomposition mode.
 * @author Christoph Blume
 * @version $Revision: 1.19 $
 * 
 * @see DefineCommand
 * @see Console.Environment.Type
 *
 */
public final class AddCommand extends Command {
	
	private static final File ADD_DOCUMENTATION_FILE = new File(
			RavenMain.DOCUMENTATION_FOLDER + "AddCommandDocumentation.txt");
	
	private static final String ADD_KEY = Console.ADD_TOKEN;
	private static final String OPERATION_PATTERN = Console.OPERATION_PATTERN;
	
	private static AddCommand command;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Static Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Returns the <tt>ADD</tt>-command.
	 * @return the <tt>ADD</tt>-command
	 */
	protected static AddCommand getCommand() {
		if(command==null) {
			command = new AddCommand();
		}

		return command;		
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates the <tt>ADD</tt>-command.
	 */
	private AddCommand() {
		super(ADD_KEY, ConsoleMessages.ADD_DESCRIPTION_KEY, 
				ADD_DOCUMENTATION_FILE);
	}

	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	@Override
	public boolean matchesParameter(String line) {
		return line.matches(OPERATION_PATTERN);
	}

	@Override
	public void execute(String parameter) {
		if(!matchesParameter(parameter)) {
			throw new IllegalArgumentException(
					Console.messages.getString(ConsoleMessages.WRONG_PARAMETER_DESCRIPTION_KEY, ADD_KEY));
		}
		
		Environment.decomposition.add(Operation.parse(parameter));
	}

}
