/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.cli;

import de.uni_due.inf.ti.raven.messages.Messages;

/**
 * This class provides the keys for the various CLI messages which can be obtained from 
 * the underlying resource bundles.
 * @author Christoph Blume
 * @version $Revision: 1.48 $
 * 
 * @see Messages
 *
 */
public final class ConsoleMessages extends Messages {

	// Exit Status Message Keys
	
	/** Exit Status Message Keys */
	public static final String[] EXIT_STATUS_KEY = {
		"raven.exit.unexpectedError",
		"raven.exit.saveDirCreationFailed",
		"raven.exit.scriptDirCreationFailed",
		"raven.exit.tempDirCreationFailed",
		"raven.exit.securityException",
		"raven.exit.fileNotFoundException",
		"raven.exit.iOException",
		"raven.exit.outOfMemory",
		"raven.exit.unknownOption"
	};
	
	// Command Description Keys
		
	/** ADD command description key */
	public static final String ADD_DESCRIPTION_KEY = "raven.command.add";

	/** ALIAS command description key */
	public static final String ALIAS_DESCRIPTION_KEY = "raven.command.alias";
	
	/** AUTOMATON command description key */
	public static final String AUTOMATON_DESCRIPTION_KEY = "raven.command.automaton";
	
	/** COSPAN DEFINITION MODE COMMANDS key */
	public static final String COSPAN_DEFINITION_MODE_COMMANDS_KEY = "raven.command.cospanDefinitionModeCommands";
	
	/** COSPAN DEFINITION MODE STARTED key */
	public static final String COSPAN_DEFINITION_MODE_STARTED_KEY = "raven.command.cospanDefinitionModeStarted";

	/** DECOMPOSITION DEFINITION MODE COMMANDS key */
	public static final String DECOMPOSITION_DEFINITION_MODE_COMMANDS_KEY = "raven.command.decompositionDefinitionModeCommands";
	
	/** DEFINE command description key */
	public static final String DEFINE_DESCRIPTION_KEY = "raven.command.define";
	
	/** DELETE command description key */
	public static final String DELETE_DESCRIPTION_KEY = "raven.command.delete";
	
	/** EDGE command description key */
	public static final String EDGE_DESCRIPTION_KEY = "raven.command.edge";
	
	/** EMPTINESS command description key */
	public static final String EMPTINESS_DESCRIPTION_KEY = "raven.command.emptiness";
	
	/** END command description key */
	public static final String END_DESCRIPTION_KEY = "raven.command.end";
	
	/** EXIT command description key */
	public static final String EXIT_DESCRIPTION_KEY = "raven.command.exit";

	/** GRAPH DEFINITION MODE COMMANDS key */
	public static final String GRAPH_DEFINITION_MODE_COMMANDS_KEY = "raven.command.graphDefinitionModeCommands";
	
	/** HELP command description key */
	public static final String HELP_DESCRIPTION_KEY = "raven.command.help";
	
	/** INFO command description key */
	public static final String INFO_DESCRIPTION_KEY = "raven.command.info";
	
	/** INNER INTERFACE command description key */
	public static final String INNER_INTERFACE_DESCRIPTION_KEY = "raven.command.innerInterface";
	
	/** INVARIANT command description key */
	public static final String INVARIANT_DESCRIPTION_KEY = "raven.command.invariant";
	
	/** LANGUAGE INCLUSION command description key */
	public static final String LANGUAGE_INCLUSION_DESCRIPTION_KEY = "raven.command.languageInclusion";
	
	/** LOAD command description key */
	public static final String LOAD_DESCRIPTION_KEY = "raven.command.load";
	
	/** MEMBERSHIP command description key */
	public static final String MEMBERSHIP_DESCRIPTION_KEY = "raven.command.membership";
	
	/** NODE command description key */
	public static final String NODE_DESCRIPTION_KEY = "raven.command.node";
	
	/** PRINT command description key */
	public static final String PRINT_DESCRIPTION_KEY = "raven.command.print";
	
	/** PRINTDOT command description key */
	public static final String PRINTDOT_DESCRIPTION_KEY = "raven.command.printDot";
	
	/** OUTER INTERFACE command description key */
	public static final String OUTER_INTERFACE_DESCRIPTION_KEY = "raven.command.outerInterface";
	
	/** QUIT command description key */
	public static final String QUIT_DESCRIPTION_KEY = "raven.command.quit";
	
	/** RANDOMGRAPH command description key */
	public static final String RANDOMGRAPH_DESCRIPTION_KEY = "raven.command.randomgraph";
	
	/** REACHABILITY command description key */
	public static final String REACHABILITY_DESCRIPTION_KEY = "raven.command.reachability";
	
	/** REMOVE command description key */
	public static final String REMOVE_DESCRIPTION_KEY = "raven.command.remove";
	
	/** RENAME command description key */
	public static final String RENAME_DESCRIPTION_KEY = "raven.command.rename";
	
	/** REPOSITORY command description key */
	public static final String REPOSITORY_DESCRIPTION_KEY = "raven.command.repository";
	
	/** RUN command description key */
	public static final String RUN_DESCRIPTION_KEY = "raven.command.run";
	
	/** SAVE command description key */
	public static final String SAVE_DESCRIPTION_KEY = "raven.command.save";
	
	/** SET command description key */
	public static final String SET_DESCRIPTION_KEY = "raven.command.set";
	
	/** SHOW command description key */
	public static final String SHOW_DESCRIPTION_KEY = "raven.command.show";
	
	/** SIGNATURE command description key */
	public static final String SIGNATURE_DESCRIPTION_KEY = "raven.command.signature";
	
	/** SIMULATION command description key */
	public static final String SIMULATION_DESCRIPTION_KEY = "raven.command.simulation";
	
	/** TEST command description key */
	public static final String TEST_DESCRIPTION_KEY = "raven.command.test";
	
	/** UNIVERSALITY command description key */
	public static final String UNIVERSALITY_DESCRIPTION_KEY = "raven.command.universality";
	
	/** UPDATE command description key */
	public static final String UPDATE_DESCRIPTION_KEY = "raven.command.update";

	/** Exit definition mode description key */
	public static final String EXIT_DEFINITION_MODE_DESCRIPTION_KEY = "raven.command.exitDefinitionMode";

	/** Get additional help description key */
	public static final String GET_ADDITIONAL_HELP_DESCRIPTION_KEY = "raven.command.getAdditionalHelp";
	
	/** Get help description key */
	public static final String GET_HELP_DESCRIPTION_KEY = "raven.command.getHelp";
	
	/** Missing illegal argument description key */
	public static final String MISSING_ILLEGAL_ARGUMENT_DESCRIPTION_KEY = "raven.command.missingIllegalArgument";
	
	/** No print action available description key */
	public static final String NO_PRINT_ACTION_AVAILABLE_DESCRIPTION_KEY = "raven.command.noPrintActionAvailable";
	
	/** Unknown command description key */
	public static final String UNKNOWN_COMMAND_DESCRIPTION_KEY = "raven.command.unknownCommand";
	
	/** Unknown Variable description key */
	public static final String UNKNOWN_VARIABLE_DESCRIPTION_KEY = "raven.command.unknownVariable";
	
	/** Wrong parameter description key */
	public static final String WRONG_PARAMETER_DESCRIPTION_KEY = "raven.command.wrongParameter";

	
	// Exception Keys
	
	/** Cospan Already Exists Exception Key */
	public static final String COSPAN_ALREADY_EXISTS_EXCEPTION_KEY = "raven.exception.cospanAlreadyExists";

	/** Cospan Decomposition Already Exists Exception Key */
	public static final String COSPAN_DECOMPOSITION_ALREADY_EXISTS_EXCEPTION_KEY = "raven.exception.cospanDecompositionAlreadyExists";
	
	/** Cospan Decomposition Failed Exception Key */
	public static final String COSPAN_DECOMPOSITION_FAILED_EXCEPTION_KEY = "raven.exception.decompositionFailed";

	/** Divisor Less Than One Exception Key */
	public static final String DIVISOR_LESS_THAN_ONE_KEY = "raven.exception.divisorLessOne";
	
	/** Data Not Found Exception Key */
	public static final String DATA_NOT_FOUND_EXCEPTION_KEY = "raven.exception.dataNotFound";
	
	/** Data Renaming Failed Exception Key  */
	public static final String DATA_RENAMING_FAILED_KEY = "raven.exception.dataRenamingFailed";
	
	/** Directory Not Created Exception Key */
	public static final String DIRECTORY_NOT_CREATED_KEY = "raven.exception.directoryNotCreated";
	
	/** Empty String Exception Key */
	public static final String EMPTY_STRING_KEY = "raven.exception.emptyString";

	/**  */
	public static final String EXCEPTION_DURING_UPDATE_KEY = "raven.exception.exceptionDuringUpdate";
	
	/**  */
	public static final String EXCEPTION_OCCURED_KEY = "raven.exception.exceptionOccured";

	/**  */
	public static final String FILE_NOT_FOUND_KEY = "raven.exception.fileNotFound";
	
	/**  */
	public static final String FORMULA_ALREADY_EXISTS_EXCEPTION = "raven.exception.formulaAlreadyExists";
	
	/**  */
	public static final String GRAPH_ALREADY_EXISTS_EXCEPTION = "raven.exception.graphAlreadyExists";

	/** */
	public static final String ILLEGAL_OPERATION_KEY = "raven.exception.illegalOperation";
	
	/**  */
	public static final String MAXIMUM_GREATER_THAN_MAXIMUM_INTERFACE_KEY = "raven.exception.maximumGreaterThanMaximumInterface";
	
	/**  */
	public static final String MAXIMUM_LESS_THAN_ZERO_KEY = "raven.exception.maximumLessZero";

	/**  */
	public static final String MINIMUM_GREATER_THAN_MAXIMUM_INTERFACE_KEY = "raven.exception.minimumGreaterThanMaximumInterface";
	
	/**  */
	public static final String MINIMUM_LESS_THAN_ZERO_KEY = "raven.exception.minimumLessZero";
	
	/**  */
	public static final String NULL_POINTER_KEY = "raven.exception.nullPointer";
	
	/**  */
	public static final String OUT_OF_MEMORY_KEY = "raven.exception.outOfMemory";
	
	/**  */
	public static final String REMAINDER_GREATER_OR_EQUAL_THAN_DIVISOR_KEY = "raven.exception.remainderGreaterOrEqualDivisor";
	
	/**  */
	public static final String REMAINDER_LESS_THAN_ZERO_KEY = "raven.exception.remainderLessZero";

	/**  */
	public static final String SAVING_ERROR_OCCURED = "raven.exception.savingFile";
	
	
	// Message File Keys

	/**  */
	public static final String ACTIVATED_KEY = "raven.text.activated";

	/** Automaton Text Key */
	public static final String AUTOMATON_KEY = "raven.text.automaton";
	
	/**  */
	public static final String AUTOMATON_ADDED_KEY = "raven.text.automatonAdded";

	/**  */
	public static final String AUTOMATON_NAME_IS_EMPTY_KEY = "raven.text.automatonNameIsEmpty";
	
	/**  */
	public static final String AUTOMATON_NAME_IS_NULL_KEY = "raven.text.automatonNameIsNull";
	
	/** Automaton Not Found Text Key */
	public static final String AUTOMATON_NOT_FOUND_KEY = "raven.text.automatonNotFound";
	
	/**  */
	public static final String AUTOMATON_SAVED_KEY = "raven.text.automatonSaved";
	
	/** BDD Size Text Key */
	public static final String BDD_SIZE_KEY = "raven.text.bddSize";
	
	/** Checking Invariant using the Antichain Algorithm Text Key */
	public static final String CHECK_INVARIANT_ANTICHAIN = "raven.text.checkInvariantAntichain";
	
	/** Checking Invariant using the Bisimulation up-to Algorithm Text Key */
	public static final String CHECK_INVARIANT_BISIMULATION_UP_TO = "raven.text.checkInvariantBisimulationUpTo";
	
	/** Checking Invariant using the Simulation-based Antichain Algorithm Text Key */
	public static final String CHECK_INVARIANT_SIMULATION_ANTICHAIN = "raven.text.checkInvariantSimulationAntichain";
	
	/**  */
	public static final String COMPUTATION_INTERRUPTED_KEY = "raven.text.computationInterrupted";

	/** Computing Cospan Decomposition Text Key */
	public static final String COMPUTING_COSPAN_DECOMPOSITION_KEY = "raven.text.computeCospanDecomposition";
	
	/** Computing Graph Decomposition Text Key  */
	public static final String COMPUTING_GRAPH_DECOMPOSITION_KEY = "raven.text.computeGraphDecomposition";
	
	/** Computing Language Inclusion Text Key */
	public static final String COMPUTING_LANGUAGE_INCLUSION_KEY = "raven.text.computeLanguageInclusion";
	
	/** Cospan Text Key */
	public static final String COSPAN_KEY = "raven.text.cospan";
	
	/** Cospan Added Text Key */
	public static final String COSPAN_ADDED_KEY = "raven.text.cospanAdded";

	/** Cospan Not Found Text Key  */
	public static final String COSPAN_NOT_FOUND_KEY = "raven.text.cospanNotFound";
	
	/** Cospan Saved Text Key */
	public static final String COSPAN_SAVED_KEY = "raven.text.cospanSaved";
	
	/** Counter Example Found Text Key  */
	public static final String COUNTER_EXAMPLE_FOUND_KEY = "raven.text.counterExampleFound";
	
	/** Cospan Or Decomposition Not Found Text Key  */
	public static final String COSPAN_OR_DECOMPOSITION_NOT_FOUND_KEY = "raven.text.cospanOrDecompositionNotFound";
	
	/** Data Can Not Be Saved Text Key */
	public static final String DATA_CAN_NOT_BE_SAVED_KEY = "raven.text.dataCanNotBeSaved";
	
	/** Data Not Found Text Key */
	public static final String DATA_NOT_FOUND_KEY = "raven.text.dataNotExisting";
	
	/** Data Removed Text Key */
	public static final String DATA_REMOVED_KEY = "raven.text.dataRemoved";
	
	/** Data Renamed Successfully Text Key */
	public static final String DATA_RENAMED_SUCCESSFULLY_KEY = "raven.text.dataRenamedSuccessfully";
	
	/** Deactivated Text Key  */
	public static final String DEACTIVATED_KEY = "raven.text.deactivated";
	
	/** Decomposition Text Key */
	public static final String DECOMPOSITION_KEY = "raven.text.decomposition";
	
	/** Decomposition Added Text Key */
	public static final String DECOMPOSITION_ADDED_KEY = "raven.text.decompositionAdded";
	
	/** Decomposition Not Found Text Key */
	public static final String DECOMPOSITION_NOT_FOUND_KEY = "raven.text.decompositionNotFound";
	
	/** Decomposition Printed Text Key */ 
	public static final String DECOMPOSITION_PRINTED_KEY = "raven.text.decompositionPrinted";

	/** Decomposition Saved Text Key */ 
	public static final String DECOMPOSITION_SAVED_KEY = "raven.text.decompositionSaved";
	
	/** Density Must Not Be Less Than 0 Text Key */
	public static final String DENSITY_MUST_NOT_BE_LESS_THAN_ZERO_KEY = "raven.text.densityMustNotBeLessThanZero";
	
	/** Density Must Not Be Greater Than 100 Text Key */
	public static final String DENSITY_MUST_NOT_BE_GREATER_THAN_HUNDRED_KEY = "raven.text.densityMustNotBeGreaterThanHundred";
	
	/** Different Inner Interfaces Text Key */
	public static final String DIFFERENT_INNER_INTERFACES_KEY = "raven.text.differentInnerInterfaces";
	
	/** Different Maximum Interfaces Text Key */
	public static final String DIFFERENT_MAXIMUM_INTERFACES_KEY = "raven.text.differentMaximumInterfaces";
	
	/** Different Signatures Text Key */
	public static final String DIFFERENT_SIGNATURES_KEY = "raven.text.differentSignatures";
	
	/** Edge Text Key */
	public static final String EDGE_KEY = "raven.text.edge";
	
	/**  */
	public static final String ELAPSED_TIME_KEY = "raven.text.elapsedTime";
	
	/**  */
	public static final String EMPTINESS_DOES_HOLD_KEY = "raven.text.emptinessDoesHold";

	/**  */
	public static final String EMPTINESS_DOES_NOT_HOLD_KEY = "raven.text.emptinessDoesHold";

	/** Encoding Text Key */
	public static final String ENCODING_KEY = "raven.text.encoding";
	
	/**  */
	public static final String FILE_ALREADY_EXISTING_KEY = "raven.text.fileAlreadyExisting";
	
	/**  */
	public static final String FORMULA_ADDED_KEY = "raven.text.formulaAdded";

	/**  */
	public static final String GOODBYE_KEY = "raven.text.goodbye";
	
	/**  */
	public static final String GRAPH_ADDED_KEY = "raven.text.graphAdded";

	/** Graph Decomposition Text Key */
	public static final String GRAPH_DECOMPOSITION_KEY = "raven.text.graphDecomposition";
	
	/** Graph Not Found Text Key */
	public static final String GRAPH_NOT_FOUND_KEY = "raven.text.graphNotFound";
	
	/** Graph Printed Text Key */
	public static final String GRAPH_PRINTED_KEY = "raven.text.graphPrinted";
	
	/** Graph Saved Text Key */
	public static final String GRAPH_SAVED_KEY = "raven.text.graphSaved";
	
	/** Inner Interface Text Key */
	public static final String INNER_INTERFACE_KEY = "raven.text.innerInterface";

	/** Information Text Key */
	public static final String INFORMATION_KEY = "raven.text.information";
	
	/** Interface Sizes Text Key */
	public static final String INTERFACE_SIZES_KEY = "raven.text.interfaceSizes";
	
	/**  */
	public static final String IS_AN_INVARIANT_KEY = "raven.text.isAnInvariant";
	
	/**  */
	public static final String IS_NOT_AN_INVARIANT_KEY = "raven.text.isNotAnInvariant";

	/** Empty Label Text Key */
	public static final String LABEL_MUST_NOT_BE_EMPTY_KEY = "raven.text.labelMustNotBeEmpty";
	
	/**  */
	public static final String LANGUAGE_INCLUSION_DOES_HOLD = "raven.text.languageInclusionDoesHold";
	
	/**  */
	public static final String LANGUAGE_INCLUSION_DOES_NOT_HOLD = "raven.text.languageInclusionDoesNotHold";

	/** Left Hand-Side Text Key */
	public static final String LEFT_HAND_SIDE_KEY = "raven.text.leftHandSide";
	
	/** Length Text Key */
	public static final String LENGTH_KEY = "raven.text.length";
	
	/** Maximum Interface Text Key */
	public static final String MAXIMUM_INTERFACE_KEY = "raven.text.maximumInterface";
	
	/** Middle Graph Text Key */
	public static final String MIDDLE_GRAPH_KEY = "raven.text.middleGraph";

	/** Name Text Key */
	public static final String NAME_KEY = "raven.text.name";
	
	/** Empty Name Text Key */
	public static final String NAME_MUST_NOT_BE_EMPTY_KEY = "raven.text.nameMustNotBeEmpty";
	
	/** No Documentation Text Key */
	public static final String NO_DOCUMENTATION_KEY = "raven.text.noDocumentation";

	/** No Update Available Text Key */
	public static final String NO_UPDATE_AVAILABLE_KEY = "raven.text.noUpdateAvailable";
	
	/** Node Text Key */
	public static final String NODE_KEY = "raven.text.node";
	
	/** Node Already Existing Text Key */
	public static final String NODE_ALREADY_EXISTING_KEY = "raven.text.nodeAlreadyExisting";
	
	/** Node Already In Outer Interface Text Key */
	public static final String NODE_ALREADY_IN_OUTER_INTERFACE_KEY = "raven.text.nodeAlreadyInOuterInterface";
	
	/** Node Not Existing Text Key */
	public static final String NODE_NOT_EXISTING_KEY = "raven.text.nodeNotExisting";

	/** Operation Text Key */
	public static final String OPERATION_KEY = "raven.text.operation";
	
	/** Outer Interface Text Key */
	public static final String OUTER_INTERFACE_KEY = "raven.text.outerInterface";
	
	/** Overwrite File Text Key */
	public static final String OVERWRITE_FILE_KEY = "raven.text.overwriteFile";

	/** Path Decomposition Text Key */
	public static final String PATH_DECOMPOSITION_KEY = "raven.text.pathDecomposition";
	
	/** Path Decomposition Added Text Key */
	public static final String PATH_DECOMPOSITION_ADDED_KEY = "raven.text.pathDecompositionAdded";

	/** Right Hand-Side Text Key */
	public static final String RIGHT_HAND_SIDE_KEY = "raven.text.rightHandSide";
	
	/** Running Scripts In Script Mode Text Key */
	public static final String RUNNING_SCRIPTS_IN_SCRIPT_MODE_KEY = "raven.text.runningScriptsInScriptMode";
	
	/** Signature Text Key */
	public static final String SIGNATURE_KEY = "raven.text.signature";
	
	/** Signature Added Text Key */
	public static final String SIGNATURE_ADDED_KEY = "raven.text.signatureAdded";
	
	/** Signature Not Found Text Key */
	public static final String SIGNATURE_NOT_FOUND_KEY = "raven.text.signatureNotFound";
	
	/** Signature Saved Text Key */
	public static final String SIGNATURE_SAVED_KEY = "raven.text.signatureSaved";
	
	/** Sloppy Mode Set Text Key */
	public static final String SLOPPY_MODE_SET_KEY = "raven.text.sloppyModeChanged";
	
	/** States Text Key */
	public static final String STATES_KEY = "raven.text.states";
	
	/** States Printed Text Key */
	public static final String STATES_PRINTED_KEY = "raven.text.statesPrinted";
	
	/** Table Header Name Text Key */
	public static final String TABLE_HEADER_NAME_KEY = "raven.text.tableHeaderName";
	
	/** Table Header Type Text Key */
	public static final String TABLE_HEADER_TYPE_KEY = "raven.text.tableHeaderType";
	
	/** Time Statistics Mode Set Text Key */
	public static final String TIME_MODE_SET_KEY = "raven.text.timeModeChanged";
	
	/** Total Text Key */
	public static final String TOTAL_KEY = "raven.text.total";
	
	/** Transition Graph Printed Text Key*/
	public static final String TRANSITION_GRAPH_PRINTED_KEY = "raven.text.transitionGraphPrinted";
	
	/** Tree Decomposition Text Key */
	public static final String TREE_DECOMPOSITION_KEY = "raven.text.treeDecomposition";
	
	/**  */
	public static final String TREE_DECOMPOSITION_ADDED_KEY = "raven.text.treeDecompositionAdded";

	/** Type Text Key */
	public static final String TYPE_KEY = "raven.text.type";

	/**  */
	public static final String UNIVERSALITY_DOES_HOLD = "raven.text.universalityDoesHold";
	
	/**  */
	public static final String UNIVERSALITY_DOES_NOT_HOLD = "raven.text.universalityDoesNotHold";
	
	/**  */
	public static final String UNKNOWN_NODE_KEY = "raven.text.unknownNode";
	
	/**  */
	public static final String UPDATE_AVAILABLE = "raven.text.updateAvailable";
	
	/**  */
	public static final String UPDATE_BUILD_PARSER_FAILED_KEY = "raven.text.updateBuildParserFailed";

	/**  */
	public static final String UPDATE_DOWNLOAD_WAS_CORRUPTED_KEY = "raven.text.updateDownloadCorrupted";

	/**  */
	public static final String UPDATE_FAILED_KEY = "raven.text.updateFailed";
	
	/**  */
	public static final String UPDATE_FILES_NOT_FOUND_KEY = "raven.text.updateFilesNotFound";
	
	/**  */
	public static final String UPDATE_IOERROR_OCCURRED_KEY = "raven.text.updateIOErrorOccurred";
	
	/**  */
	public static final String UPDATE_LOCATION_INVALID_KEY = "raven.text.updateLocationInvalid";
	
	/**  */
	public static final String UPDATE_SCHEMA_FILE_CORRUPTED_KEY = "raven.text.updateSchemaCorrupted";

	/**  */
	public static final String UPDATE_SCHEMA_FILE_NOT_FOUND_KEY = "raven.text.updateSchemaNotFound";
	
	/**  */
	public static final String UPDATE_SUCCESSFUL = "raven.text.updateSuccessful";
	
	/** Verbose Mode Set Text Key */
	public static final String VERBOSE_MODE_SET_KEY = "raven.text.verboseModeChanged";

	/** Width Is Greater Than The Maximum Interface Size Text Key */
	public static final String WIDTH_GREATER_THAN_MAXIMUM_INTERFACE_KEY = "raven.text.widthGreaterThanMaximumInterface";
	
	/**  */
	public static final String YES_OR_NO_OPTION = "raven.text.yesOrNoOption";
	
	
	//Message Bundle Name
	private static final String BUNDLE_NAME = "de.uni_due.inf.ti.raven.messages.raven-cli-messages";
	
	private static ConsoleMessages consoleMessages;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Static Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Returns a named list of all console messages.
	 * @return the console messages
	 */
	public static ConsoleMessages getMessages() {
		if(consoleMessages==null) {
			consoleMessages = new ConsoleMessages();
		}
		
		return consoleMessages;
	}
		
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates a new named list for the console messages.
	 */
	private ConsoleMessages() {
		super(BUNDLE_NAME);
	}
	
}
