/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.cli;

/**
 * Console command to handle the removal of data from the repository.
 * @see DefineCommand
 * @see Console.Environment.Type
 * @author Christoph Blume
 * @version $Revision: 1.13 $
 *
 * @see RemoveCommand
 */
public class DeleteCommand extends AliasCommand {

	/** */
	protected static final String DELETE_KEY = Console.DELETE_TOKEN;
	
	private static DeleteCommand command;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Static Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Returns the <tt>DELETE</tt>-command.
	 * @return the <tt>DELETE</tt>-command
	 */
	protected static DeleteCommand getCommand() {
		if(command==null) {
			command = new DeleteCommand();
		}

		return command;		
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates the <tt>DELETE</tt>-command.
	 */
	private DeleteCommand() {
		super(DELETE_KEY, RemoveCommand.getCommand());
	}

}
