/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.cli;

import java.io.File;
import java.util.List;

import de.uni_due.inf.ti.raven.cli.Console.Environment;
import de.uni_due.inf.ti.raven.data.Cospan;
import de.uni_due.inf.ti.raven.main.RavenMain;

/**
 * Console command to handle the addition of nodes to the inner interface in 
 * cospan definition mode.
 * @author Christoph Blume
 * @version $Revision: 1.4 $
 * 
 * @see DefineCommand
 * @see Console.Environment.Type
 *
 */
public final class InnerInterfaceCommand extends Command {
	
	private static final File INNER_INTERFACE_DOCUMENTATION_FILE = new File(
			RavenMain.DOCUMENTATION_FOLDER + "InnerInterfaceCommandDocumentation.txt");
	
	private static final String INNER_INTERFACE_KEY = Console.INNER_TOKEN;
	
	private static final String NAME_PATTERN = Console.NAME_PATTERN;
	private static final String ADD_TO_INNER_INTERFACE_PATTERN = "("+NAME_PATTERN+")";
	
	private static InnerInterfaceCommand command;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Static Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Returns the <tt>INNER</tt>-command.
	 * @return the <tt>INNER</tt>-command
	 */
	protected static InnerInterfaceCommand getCommand() {
		if(command==null) {
			command = new InnerInterfaceCommand();
		}

		return command;		
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates the <tt>INNER</tt>-command.
	 */
	private InnerInterfaceCommand() {
		super(INNER_INTERFACE_KEY, ConsoleMessages.INNER_INTERFACE_DESCRIPTION_KEY, 
				INNER_INTERFACE_DOCUMENTATION_FILE);
	}

	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	@Override
	public boolean matchesParameter(String line) {
		return line.matches(ADD_TO_INNER_INTERFACE_PATTERN);
	}

	@Override
	public void execute(String parameter) {
		if(!matchesParameter(parameter)) {
			throw new IllegalArgumentException(
					Console.messages.getString(ConsoleMessages.WRONG_PARAMETER_DESCRIPTION_KEY, INNER_INTERFACE_KEY));
		}
		
		Cospan cospan = Environment.cospan;
		List<String> list = getProperties(parameter, ADD_TO_INNER_INTERFACE_PATTERN);
		String nodeName = list.get(0);
		if(nodeName.isEmpty()) {
			Console.out.println(messages.getString(ConsoleMessages.NAME_MUST_NOT_BE_EMPTY_KEY));
		}
		else if(!cospan.hasNode(nodeName)) {
			Console.out.println(messages.getString(ConsoleMessages.NODE_NOT_EXISTING_KEY, nodeName));
		}
		else {
			Environment.cospan.addToInnerInterface(list.get(0));
		}
		
	}

}
