/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.cli;

import java.io.File;

import de.uni_due.inf.ti.raven.cli.Console.Environment;
import de.uni_due.inf.ti.raven.main.RavenMain;

/**
 * Console command to handle the addition of nodes in cospan/graph mode.
 * @author Christoph Blume
 * @version $Revision: 1.18 $
 * 
 * @see DefineCommand
 * @see EdgeCommand
 * @see Console.Environment.Type
 *
 */
public final class NodeCommand extends Command {

	private static final File NODE_DOCUMENTATION_FILE = new File(
			RavenMain.DOCUMENTATION_FOLDER + "NodeCommandDocumentation.txt");
	
	private static final String NAME_PATTERN = Console.NAME_PATTERN;
	
	private static final String NODE_KEY = Console.NODE_TOKEN;
	private static final String NODE_PATTERN = "("+NAME_PATTERN+")";
	
	private static NodeCommand command;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Static Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Returns the <tt>NODE</tt>-command.
	 * @return the <tt>NODE</tt>-command
	 */
	protected static NodeCommand getCommand() {
		if(command==null) {
			command = new NodeCommand();
		}

		return command;		
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates the <tt>NODE</tt>-command.
	 */
	private NodeCommand() {
		super(NODE_KEY, ConsoleMessages.NODE_DESCRIPTION_KEY, 
				NODE_DOCUMENTATION_FILE);
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/

	@Override
	public boolean matchesParameter(String line) {
		return line.matches(NODE_PATTERN);
	}

	@Override
	public void execute(String parameter) {
		if(!matchesParameter(parameter)) {
			throw new IllegalArgumentException(Console.messages.getString(
					ConsoleMessages.MISSING_ILLEGAL_ARGUMENT_DESCRIPTION_KEY, NODE_KEY));
		}

		String nodeName = getProperties(parameter, NODE_PATTERN).get(0);
		if(Console.Environment.getType()==Console.Environment.Type.COSPAN) {
			if(nodeName.isEmpty()) {
				Console.out.println(messages.getString(
						ConsoleMessages.NAME_MUST_NOT_BE_EMPTY_KEY, nodeName));
			}
			else if(Environment.cospan.hasNode(nodeName)) {
				Console.out.println(messages.getString(
						ConsoleMessages.NODE_ALREADY_EXISTING_KEY, nodeName));
			}
			else {				
				Environment.cospan.addNode(nodeName);
			}
		}
		else if(Console.Environment.getType()==Console.Environment.Type.GRAPH) {
			Environment.graph.addNode(nodeName);
		}
	}

}
