/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.cli;

import java.io.File;
import java.util.List;

import de.uni_due.inf.ti.raven.actions.RemoveAction;
import de.uni_due.inf.ti.raven.main.RavenMain;

/**
 * Console command to handle the removal of data from the repository.
 * @author Christoph Blume
 * @version $Revision: 1.20 $
 *
 */
public class RemoveCommand extends Command {

	private static final File REMOVE_DOCUMENTATION_FILE = new File(
			RavenMain.DOCUMENTATION_FOLDER + "RemoveCommandDocumentation.txt");
	
	/** */
	protected static final String REMOVE_KEY = Console.REMOVE_TOKEN;
	
	private static final String NAME_PATTERN = Console.NAME_PATTERN;
	private static final String REMOVE_PARAMETER = "("+NAME_PATTERN+")";
	
	private static RemoveCommand command;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Static Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Returns the <tt>REMOVE</tt>-command.
	 * @return the <tt>REMOVE</tt>-command
	 */
	protected static RemoveCommand getCommand() {
		if(command==null) {
			command = new RemoveCommand();
		}

		return command;
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates the <tt>REMOVE</tt>-command.
	 */
	private RemoveCommand() {
		super(REMOVE_KEY, ConsoleMessages.REMOVE_DESCRIPTION_KEY, 
				REMOVE_DOCUMENTATION_FILE);
	}

	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	@Override
	public boolean matchesParameter(String line) {
		return line.matches(REMOVE_PARAMETER);
	}

	@Override
	public void execute(String parameter) {
		if(!matchesParameter(parameter)) {
			System.out.println("parameter = "+parameter+", REMOVE_PARAMETER = "+REMOVE_PARAMETER);
			throw new IllegalArgumentException(Console.messages.getString(
					ConsoleMessages.MISSING_ILLEGAL_ARGUMENT_DESCRIPTION_KEY, REMOVE_KEY));
		}
		
		//Extract parameter from input string
		List<String> list = getProperties(parameter, REMOVE_PARAMETER);
		String name = list.get(0);
		
		if(!Console.repo.contains(name)) {
			throw new IllegalArgumentException(Console.messages.getString(
					ConsoleMessages.DATA_NOT_FOUND_EXCEPTION_KEY, REMOVE_KEY, name));
		}
		
		RemoveAction action = new RemoveAction(name);
		action.execute();
		if(action.getResult()) {
			Console.out.println(ConsoleMessages.getMessages().getString(
					ConsoleMessages.DATA_REMOVED_KEY, name));
		}
	}

}
