/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.cli;

import java.io.File;

import de.uni_due.inf.ti.raven.actions.ColorabilityAutomatonAction;
import de.uni_due.inf.ti.raven.data.Operation;
import de.uni_due.inf.ti.raven.data.Repository;
import de.uni_due.inf.ti.raven.data.Signature;
import de.uni_due.inf.ti.raven.data.automata.ColorabilityAutomaton;
import de.uni_due.inf.ti.raven.data.bdd.RavenBDD;
import de.uni_due.inf.ti.raven.main.RavenMain;

/**
 * @author Christoph Blumea
 *
 */
public final class TestCommand extends Command {

	private static final File DECOMPOSE_DOCUMENTATION_FILE = new File(
			RavenMain.DOCUMENTATION_FOLDER + "TestCommandDocumentation.txt");

	private static final String TEST_KEY = Console.TEST_TOKEN;

	private static TestCommand command;

	
	/*------------------------------------------------------------------------------------------*/
	/*		Static Methods																		*/
	/*------------------------------------------------------------------------------------------*/

	/**
	 * Returns the <tt>TEST</tt>-command.
	 * @return the <tt>TEST</tt>-command
	 */
	protected static TestCommand getCommand() {
		if(command==null) {
			command = new TestCommand();
		}

		return command;		
	}


	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/

	/**
	 * Creates the <tt>TEST</tt>-command.
	 */
	private TestCommand() {
		super(TEST_KEY, ConsoleMessages.INVARIANT_DESCRIPTION_KEY, 
				DECOMPOSE_DOCUMENTATION_FILE);
	}

	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/

	@Override
	public boolean matchesParameter(String line) {
		return line.matches("");
	}

	@Override
	public void execute(String parameter) {
		//Do Nothing
		Signature sig = new Signature();
		sig.add(Operation.getConnect("A", 2));
		sig.add(Operation.getPerm());
		sig.add(Operation.getRes());
		sig.add(Operation.getTrans());
		sig.add(Operation.getVertex());
		
		ColorabilityAutomatonAction action = new ColorabilityAutomatonAction(5, 0, 0, sig, 3);
		action.execute();
		ColorabilityAutomaton col = action.getResult();
		Repository.getRepository().put("col", col);
		
		RavenBDD trans = col.getTransitionRelation(Operation.getConnect("A", 2));
		col.getEncoding().getCurrentStateDomain().getBDDForInteger(3, 3).printDot(System.out);
		trans = trans.and(col.getEncoding().getCurrentStateDomain().getBDDForInteger(3, 3));
		trans.printDot(System.out);
	}

}
