/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.data;

import de.uni_due.inf.ti.raven.io.ConsolePrinter;

/**
 * A wrapper class for cospan decompositions that are used to give one 
 * graph as a counter-example for an algorithm  
 * @author Christoph Blume, Dennis Nolte
 * @version $Revision: 1.7 $
 */

public class CospanCounterExample implements CounterExample {
	
	private CospanDecomposition cd;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates a new cospan counter-example
	 * @param cd the cospan decomposition of the calculated counter-example graph
	 */
	public CospanCounterExample(CospanDecomposition cd)
	{
		this.cd = new CospanDecomposition(cd);
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	@Override
	public int hashCode() {
		return 31*cd.hashCode();
	}
	
	@Override
	public boolean equals(Object o) {
		if(o==null) {
			return false;
		}
		else if(o==this) {
			return true;
		}
		else if(o.getClass().equals(getClass())) {
			CospanCounterExample counterExample = (CospanCounterExample) o;
			return counterExample.cd.equals(cd);
		}
		else {
			return false;
		}
	}
	
	/**
	 * Returns the cospan decomposition of the counter-example graph.
	 * @return the cospan decomposition of the counter-example graph
	 */
	public CospanDecomposition getCospan() {
		return new CospanDecomposition(cd);
	}

	@Override
	public Type getType() {
		return Type.cospanCounterExample;
	}
	
	@Override
	public String toString() {
		ConsolePrinter.getPrinter().print(cd.getGraph());
		return "Decomposition: "+cd.toString();
	}

}
