/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.data;

/**
 * The {@code Decomposition} interface is the root interface in the <i>decomposition hierarchy</i>.
 * @author Christoph Blume
 * @version $Revision: 1.24 $
 *
 * @param <T> The type of the bag's elements
 * @see GraphDecomposition
 * @see TreeDecomposition
 * @see PathDecomposition
 * @see CospanDecomposition
 */
public interface Decomposition<T> extends Data, Iterable<T> {

	/**
	 * Enumeration of the different types of implemented decompositions.
	 * @author Christoph Blume
	 *
	 */
	public enum Type implements Data.Type {
		/** Cospan Decomposition Type */
		cospanDecomposition, 
		
		/** Path Decomposition Type */
		pathDecomposition, 
		
		/** Tree Decomposition Type */
		treeDecomposition;
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Returns the overall width of this decomposition, i.e. the size of the 
	 * largest interface of this decomposition.
	 * @return the decomposition's width
	 */
	public int getWidth();
	
	/**
	 * Returns {@code true} if and only if the decomposition is empty, i.e. it has the length zero.
	 * @return {@code true} if the decomposition is empty, {@code false} otherwise
	 */
	public boolean isEmpty();
	
	/**
	 * Returns the length of this decomposition, i.e. the number of 
	 * bags of this decomposition.
	 * @return the number of bags
	 */
	public int getLength();
	
}
