/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
*/

package de.uni_due.inf.ti.raven.gui;

import javax.swing.BorderFactory;
import javax.swing.JTextField;

import com.jgoodies.forms.builder.DefaultFormBuilder;
import com.jgoodies.forms.layout.FormLayout;

import de.uni_due.inf.ti.raven.data.Cospan;
import de.uni_due.inf.ti.raven.data.Node;
import de.uni_due.inf.ti.raven.data.Repository;
import de.uni_due.inf.ti.raven.gui.graphs.CospanView;

/**
 * This class provides a builder which is used to  create an {@code InformationPanel} 
 * for displaying information about <i>cospans</i>.
 * <i>cospans</i>.
 * @author Christoph Blume, Dennis Nolte
 * @version $Revision: 1.17 $
 *
 * @see Cospan
 */
public final class CospanInformationPanelBuilder extends 
	InformationPanelBuilder<Cospan> {

	/**
	 * 
	 * @author Christoph Blume
	 *
	 */
	private static class CospanInformationPanel extends 
		InformationPanel<Cospan> {

		private static final long serialVersionUID = 6860034365591736411L;

		private static final Repository repo = Repository.getRepository();
		
		/*------------------------------------------------------------------------------------------*/
		/* 		Public Methods																		*/
		/*------------------------------------------------------------------------------------------*/

		@Override
		public void setData(Cospan cospan) {
			cospanNameField.setText(repo.getName(cospan));
			innerInterfaceSizeField.setText(String.valueOf(cospan.getInnerInterface().size()));
			StringBuilder nodeNames = new StringBuilder();
			for(Node node: cospan.getInnerInterface()){
				nodeNames.append(node.getName() + " ");
			}
			innerInterfaceNodes.setText(nodeNames.toString());
			
			outerInterfaceSizeField.setText(String.valueOf(cospan.getOuterInterface().size()));
			nodeNames = new StringBuilder();
			for(Node node: cospan.getOuterInterface()){
				nodeNames.append(node.getName() + " ");
			}
			outerInterfaceNodes.setText(nodeNames.toString());
			
			// display the cospan
			cospanView.print(cospan);
			
		}		
	}
	private static CospanInformationPanelBuilder panelBuilder;
	private static InformationPanel<Cospan> panel;
	private static JTextField cospanNameField;
	private static JTextField innerInterfaceSizeField;
	private static JTextField outerInterfaceSizeField;
	private static JTextField innerInterfaceNodes;
	private static JTextField outerInterfaceNodes;
	private static CospanView cospanView;

	/*------------------------------------------------------------------------------------------*/
	/*		Static Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates an information panel displaying properties of a given cospan decomposition.
	 * @return the cospan decomposition information panel
	 */
	public static InformationPanel<Cospan> createPanel() {
		if(panelBuilder==null) {
			panel = new CospanInformationPanel();
			DefaultFormBuilder builder = new DefaultFormBuilder(
					new FormLayout(LAYOUT_SPECIFICATION), panel);
			panelBuilder = new CospanInformationPanelBuilder(builder);
		}
		return panel;
	}	
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates the panel on which signature information will be displayed.
	 * @param formBuilder the form builder used to build the panel
	 */
	private CospanInformationPanelBuilder(DefaultFormBuilder formBuilder) {
		super(formBuilder);
		formBuilder.getPanel().setOpaque(false);

		cospanNameField = new JTextField(10);
		cospanNameField.setEditable(false);
		cospanNameField.setOpaque(false);
		append(GuiMessages.NAME_LABEL_KEY, cospanNameField);
		
		appendSeparator();
		
		innerInterfaceSizeField = new JTextField(10);
		innerInterfaceSizeField.setEditable(false);
		innerInterfaceSizeField.setOpaque(false);
		append(GuiMessages.INNER_INTERFACE_SIZE_LABEL_KEY, innerInterfaceSizeField);

		innerInterfaceNodes = new JTextField(10);
		innerInterfaceNodes.setEditable(false);
		innerInterfaceNodes.setOpaque(false);
		append(GuiMessages.INNER_INTERFACE_LABEL_KEY, innerInterfaceNodes);

		appendSeparator();
		
		outerInterfaceSizeField = new JTextField(10);
		outerInterfaceSizeField.setEditable(false);
		outerInterfaceSizeField.setOpaque(false);
		append(GuiMessages.OUTER_INTERFACE_SIZE_LABEL_KEY, outerInterfaceSizeField);
		
		outerInterfaceNodes = new JTextField(10);
		outerInterfaceNodes.setEditable(false);
		outerInterfaceNodes.setOpaque(false);
		append(GuiMessages.OUTER_INTERFACE_LABEL_KEY, outerInterfaceNodes);

		appendSeparator();
		
		// preview of the resulting cospan
		cospanView = new CospanView();
		cospanView.setSaveButtonVisible(true);
		cospanView.setMaximizeViewButtonVisible(true);
		cospanView.setBorder(BorderFactory.createEtchedBorder());
		cospanView.setOpaque(false);
		cospanView.getViewport().setOpaque(false);
		append(cospanView, 3);
	}

}
