/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
*/

package de.uni_due.inf.ti.raven.gui;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Window;

import javax.swing.JPanel;
import javax.swing.JTextField;

import com.jgoodies.forms.builder.DefaultFormBuilder;
import com.jgoodies.forms.layout.FormLayout;

import de.uni_due.inf.ti.raven.encodings.BDDEncoding;
import de.uni_due.inf.ti.raven.gui.graphs.EncodingView;

/**
 * This class provides a dialog to display the encoding information used for some automaton. 
 * Please note that the dialog is modal, i.e. the {@code showDialog} method blocks the caller 
 * until the user's interaction is complete. 
 * @author Christoph Blume, Dennis Nolte
 * @version $Revision: 1.15 $
 *
 * @see BDDEncoding
 */
public class EncodingDialog extends RavenDialog {

	private static final long serialVersionUID = 2914473894128028658L;

	private static EncodingDialog dialog;

	private JTextField typeField;
	private EncodingView encodingView;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Static Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Shows the dialog for displaying encoding information.
	 * @param owner the parent window of the dialog
	 * @param encoding the encoding whose information will be displayed
	 */
	public static void showDialog(Window owner, BDDEncoding encoding) {
		if(dialog==null) {
			dialog = new EncodingDialog(owner);
		}
		
		dialog.encodingView.print(encoding);
		dialog.setEncoding(encoding);
		
		dialog.setVisible(true);
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates a new dialog for displaying encoding information.
	 * @param owner the parent window of this dialog
	 */
	private EncodingDialog(Window owner) {
		super(owner,"", RavenDialog.CLOSE_LAYOUT);
		
		JPanel mainPanel = createMainPanel();
		setMainPane(mainPanel);
		setPreferredSize(new Dimension(900,600));
		pack();
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Private Methods																		*/
	/*------------------------------------------------------------------------------------------*/

	/**
	 * Returns the panel which displays the encoding information.
	 * @return the main panel
	 */
	private JPanel createMainPanel() {
		JPanel panel = new JPanel();
		panel.setLayout(new BorderLayout(0, 0));
		panel.setBackground(MainWindow.BACKGROUND_COLOR);
		
		FormLayout layout = new FormLayout("left:max(40dlu;pref), 3dlu, 40dlu:grow", "");
		DefaultFormBuilder builder = new DefaultFormBuilder(layout);
		
		typeField = new JTextField("", 10);
		typeField.setEditable(false);
		typeField.setBackground(MainWindow.BACKGROUND_COLOR);
		builder.append(messages.getString(GuiMessages.TYPE_LABEL_KEY), typeField);
		
		encodingView = new EncodingView();
		
		panel.add(builder.getPanel(), BorderLayout.NORTH);
		panel.add(encodingView, BorderLayout.CENTER);
		
		return panel;
	}
	
	private void setEncoding(BDDEncoding encoding) {
		setTitle(encoding.toString());
		typeField.setText(encoding.toString());
	}

}
