/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
*/

package de.uni_due.inf.ti.raven.gui;

import de.uni_due.inf.ti.raven.messages.Messages;

/**
 * This class provides the keys for the various GUI messages which can be obtained from 
 * the underlying resource bundles.
 * @author Christoph Blume
 * @version $Revision: 1.112 $
 *
 */
public final class GuiMessages extends Messages {

	/** Empty Label */
	public static final String EMPTY_LABEL = "";
	
	/** Label Key Prefix */
	public static final String LABEL_PREFIX = "raven.label.";
	
	/** Data Type Key Prefix */
	public static final String DATA_TYPE_PREFIX_KEY = "raven.data.";

	//Message File Keys
	/* Menu Keys */
	/** File Menu Key */
	public static final String FILE_MENU_KEY = "raven.menu.fileMenu";
	
	/** Info Menu Key */
	public static final String INFO_MENU_KEY = "raven.menu.infoMenu";

	/** Load Menu Key */
	public static final String LOAD_KEY = "raven.menu.load";
	
	/** Load Automaton Menu Key */
	public static final String LOAD_AUTOMATON_KEY = "raven.menu.load.automaton";
	
	/** Load Cospan Menu Key */
	public static final String LOAD_COSPAN_KEY = "raven.menu.load.cospan";
	
	/** Load Decomposition Menu Key */
	public static final String LOAD_DECOMPOSITION_KEY = "raven.menu.load.decomposition";
	
	/** Load Graph Menu Key */
	public static final String LOAD_GRAPH_KEY = "raven.menu.load.graph";
	
	/** Load Signature Menu Key */
	public static final String LOAD_SIGNATURE_KEY = "raven.menu.load.signature";
	
//	/** Quit Menu Key */
//	private static final String QUIT_KEY = "raven.menu.quit";
	
	/** Repository Menu Key */
	public static final String REPOSITORY_MENU_KEY = "raven.menu.repositoryMenu";
	
	/** Run Menu Key */
	public static final String RUN_MENU_KEY = "raven.menu.runMenu";
	
	/** Save Menu Key */
	public static final String SAVE_KEY = "raven.menu.save";
	
	/** Save Automaton Menu Key */
	public static final String SAVE_AUTOMATON_KEY = "raven.menu.save.automaton";
	
	/** Save Cospan Menu Key */
	public static final String SAVE_COSPAN_KEY = "raven.menu.save.cospan";
	
	/** Save Graph Menu Key */
	public static final String SAVE_GRAPH_KEY = "raven.menu.save.graph";
	
	/** Save Signature Menu Key */
	public static final String SAVE_SIGNATURE_KEY = "raven.menu.save.signature";
	
	/** Save Decomposition Menu Key */
	public static final String SAVE_DECOMPOSITION_KEY = "raven.menu.save.decomposition";

	/** Update Menu Key */
	public static final String UPDATE_MENU_KEY = "raven.menu.infoMenu.update";
	
	/** Variables and Properties Menu Key */
	public static final String VAR_PROP_MENU_KEY = "raven.menu.infoMenu.varandprop";
	
	/** Version Menu Key */
	public static final String VERSION_MENU_KEY = "raven.menu.infoMenu.version";

	
	/* Label Keys */
	/** Accept Label Key */
	public static final String ACCEPT_LABEL_KEY = "raven.label.accept";

	/** Apply Signature Label Key */
	public static final String APPLY_SIGNATURE_LABEL_KEY = "raven.label.applySignature";

	/** Add Edge Label Key */
	public static final String ADD_EDGE_LABEL_KEY = "raven.label.addEdge";
	
	/** Add Node Label Key */
	public static final String ADD_NODE_LABEL_KEY = "raven.label.addNode";
	
	/** Add Operation Label Key */
	public static final String ADD_OPERATION_KEY = "raven.label.addOperation";
	
	/** Add to Repository Label Key */
	public static final String ADD_TO_REPOSITORY_LABEL_KEY = "raven.label.addToRepository";
	
	/** Algorithm Label Key */
	public static final String ALGORITHM_LABEL_KEY = "raven.label.algorithm";
	
	/** Arity Label Key */
	public static final String ARITY_LABEL_KEY = "raven.label.arity";
	
	/** Automaton File Extension Key */
	public static final String AUTOMATON_FILE_EXTENSION_KEY = "raven.label.automatonFileExtension";
	
	/** Automaton Label Key */
	public static final String AUTOMATON_LABEL_KEY = "raven.label.automaton";
	
	/** Automaton Name Label Key */
	public static final String AUTOMATON_NAME_LABEL_KEY = "raven.label.automatonName";
	
	/** Automaton Properties Label Key */
	public static final String AUTOMATON_PROPERTIES_LABEL_KEY = "raven.label.automatonProperties";
	
	/** Automaton Type Label Key */
	public static final String AUTOMATON_TYPE_LABEL_KEY = "raven.label.automatonType";
	
	/** Backward Label Key */
	public static final String BACKWARD_LABEL_KEY = "raven.label.backward";
	
	/** Bit Label Key */
	public static final String BIT_LABEL_KEY = "raven.label.bit";
	
	/** Cancel Label Key */
	public static final String CANCEL_LABEL_KEY = "raven.label.cancel";
	
	/** Close Label Key */
	public static final String CLOSE_LABEL_KEY = "raven.label.close";

	/** Color Bit Label Key */
	public static final String COLOR_BIT_LABEL_KEY = "raven.label.colorBit";
	
	/** Command Line Label Key */
	public static final String COMMAND_LINE_LABEL_KEY = "raven.label.commandLine";
	
	/** ComputeCounterExample Label Key */
	public static final String COMPUTE_COUNTER_EXAMPLE_LABEL_KEY = "raven.label.computecounterexample";

	/** Computing Label Key */
	public static final String COMPUTING_LABEL_KEY = "raven.label.computing";

	/** Connection Bit Label Key */
	public static final String CONNECTION_BIT_LABEL_KEY = "raven.label.connectionBit";
	
	/** Cospan GXL File Extension Label Key */
	public static final String COSPAN_GXL_FILE_EXTENSION_KEY = "raven.label.cospanGxlFileExtension";
	
	/** Cospan Name Label Key */
	public static final String COSPAN_NAME_LABEL_KEY = "raven.label.cospanName";
	
	/** Cospan Label Label Key */
	public static final String COSPAN_LABEL_KEY = "raven.label.Cospan";
	
	/** Cospan Decomposition Label Key */
	public static final String COSPAN_DECOMPOSITION_LABEL_KEY = "raven.label.CospanDecomposition";
	
	/** Cospan Preview Label Key */
	public static final String COSPAN_PREVIEW = "raven.label.cospanPreview";
	
	/** Counter Bit Label Key */
	public static final String COUNTER_BIT_LABEL_KEY = "raven.label.counterBit";
	
	/** Counter Bits Label Key */
	public static final String COUNTER_BITS_LABEL_KEY = "raven.label.counterBits";
	
	/** Counter-example Label Key */
	public static final String COUNTEREXAMPLE_LABEL_KEY = "raven.label.counterexample";
	
	/** Cover Bit Label Key */
	public static final String COVER_BIT_LABEL_KEY = "raven.label.coverBit";

	/** Cover Size Bits Label Key */
	public static final String COVER_SIZE_BITS_LABEL_KEY = "raven.label.coverSizeBits";
	
	/** Create Automaton Label Key */
	public static final String CREATE_AUTOMATON_LABEL_KEY = "raven.label.createAutomaton";
	
	/** Create Cospan Label Key */
	public static final String CREATE_COSPAN_LABEL_KEY = "raven.label.createCospan";

	/** Create Decomposition Label Key */
	public static final String CREATE_DECOMPOSITION_LABEL_KEY = "raven.label.createDecomposition";
	
	/** Create Graph Label Key */
	public static final String CREATE_GRAPH_LABEL_KEY = "raven.label.createGraph";
	
	/** Create Random Graph Label Key */
	public static final String CREATE_RANDOM_GRAPH_LABEL_KEY = "raven.label.createRandomGraph";
	
	/** Create Signature Label Key */
	public static final String CREATE_SIGNATURE_LABEL_KEY = "raven.label.createSignature";
	
	/** Current Interface Label Key */
	public static final String CURRENT_INTERFACE_LABEL_KEY = "raven.label.currentInterface";
	
	/** */
	public static final String DATA_INFORMATION_PANEL_KEY = "raven.label.dataInformationPanel";
	
	/** */
	public static final String DECOMPOSITION_FILE_EXTENSION_KEY = "raven.label.decompositionFileExtension";
	
	/** Decomposition Label Key */
	public static final String DECOMPOSITION_LABEL_KEY = "raven.label.decomposition";
	
	/** Decomposition Length Label Key */
	public static final String DECOMPOSITION_LENGTH_LABEL_KEY = "raven.label.decompositionLength";
	
	/** Decomposition Name Label Key */
	public static final String DECOMPOSITION_NAME_LABEL_KEY = "raven.label.decompositionName";

	/** */
	public static final String DECOMPOSITION_PREVIEW = "raven.label.decompositionPreview";	

	/** Default Label Key */
	public static final String DEFAULT_LABEL_KEY = "raven.label.default";
	
	/** Delete Label Key */
	public static final String DELETE_LABEL_KEY = "raven.label.delete";
	
	/** Divisor Label Key */
	public static final String DIVISOR_LABEL_KEY = "raven.label.divisor";
	
	/** Dominated Bit Label Key */
	public static final String DOMINATED_BIT_LABEL_KEY = "raven.label.dominatedBit";
	
	/** Dominating Set Size Label Key */
	public static final String DOMINATING_SET_SIZE_LABEL_KEY = "raven.label.dominatingSetSize";
	
	/** Edge Label Key */
	public static final String EDGE_LABEL_KEY = "raven.label.edge";

	/** Edge Bit Label Key */
	public static final String EDGE_BIT_LABEL_KEY = "raven.label.edgeBit";
	
	/** Edge Number Label Key */
	public static final String EDGE_NUMBER_LABEL_KEY = "raven.label.edgeNumber";
	
	/** Edge Order Label Key */
	public static final String EDGE_ORDER_LABEL_KEY = "raven.label.edgeOrder";
	
	/** Edge Selection Label Key */
	public static final String EDGE_SELECTION_LABEL_KEY = "raven.label.edgeSelection";
	
	/** Edges Label Key */
	public static final String EDGES_LABEL_KEY = "raven.label.edges";

	/** The Empty Interface Label Key */
	public static final String EMPTY_INTERFACE_LABEL_KEY = "raven.label.emptyInterface";
	
	/** Encoding Label Key */
	public static final String ENCODING_LABEL_KEY = "raven.label.encoding";
	
	/** Encoding Bits Label Key */
	public static final String ENCODING_BITS_LABEL_KEY = "raven.label.encodingBits";

	/** First Automaton Label Key */
	public static final String FIRST_AUTOMATON_LABEL_KEY = "raven.label.firstAutomaton";
	
	/** FormatCounterExample Label Key */
	public static final String FORMAT_COUNTER_EXAMPLE_LABEL_KEY = "raven.label.formatcounterexample";
	
	/** Forward Label Key */
	public static final String FORWARD_LABEL_KEY = "raven.label.forward";
	
	/** Graph GXL File Extension Label Key */
	public static final String GRAPH_GXL_FILE_EXTENSION_KEY = "raven.label.graphGxlFileExtension";
	
	/** Graph Cospan Label Label Key */
	public static final String GRAPH_COSPAN_LABEL_KEY = "raven.label.graphCospan";
	
	/** Graph Label Label Key */
	public static final String GRAPH_LABEL_KEY = "raven.label.graph";

	/** Graph Name Label Key */
	public static final String GRAPH_NAME_LABEL_KEY = "raven.label.graphName";
	
	/** Graph Preview Label Key */
	public static final String GRAPH_PREVIEW = "raven.label.graphPreview";
	
	/** Help Label Key */
	public static final String HELP_LABEL_KEY = "raven.label.help";

	/** Incident Nodes Label Key */
	public static final String INCIDENT_NODES_LABEL_KEY = "raven.label.incidentNodes";
	
	/** Initial Bit Label Key */
	public static final String INITIAL_BIT_LABEL_KEY = "raven.label.initialBit";
	
	/** Initial Bits Label Key */
	public static final String INITIAL_BITS_LABEL_KEY = "raven.label.initialBits";
	
	/** Inner Interface Label Key */
	public static final String INNER_INTERFACE_LABEL_KEY = "raven.label.innerInterface";
	
	/** Inner Interface Size Label Key */
	public static final String INNER_INTERFACE_SIZE_LABEL_KEY = "raven.label.innerInterfaceSize";

	/** Input Graph Label Key */
	public static final String INPUT_GRAPH_LABEL_KEY = "raven.label.inputGraph";
	
	/** Input Decomposition Label Key */
	public static final String INPUT_DECOMPOSITION_LABEL_KEY = "raven.label.inputDecomposition";

	/** Input Graph/Decomposition Label Key */
	public static final String INPUT_GRAPH_DECOMPOSITION_LABEL_KEY = "raven.label.inputGraphDecomposition";
	
	/** Interface Bits Label Key */
	public static final String INTERFACE_BITS_LABEL_KEY = "raven.label.interfaceBits";

	/** Isolation Bit Label Key */
	public static final String ISOLATION_BIT_LABEL_KEY = "raven.label.isolationBit";

	/** Isolation Bits Label Key */
	public static final String ISOLATION_BITS_LABEL_KEY = "raven.label.isolationBits";

	/** Isolation Flag Label Key */
	public static final String ISOLATION_FLAG_LABEL_KEY = "raven.label.isolationFlag";
	
	/** Key Label Key */
	public static final String KEY_LABEL_KEY = "raven.label.key";
	
	/** Label Label Key */
	public static final String LABEL_LABEL_KEY = "raven.label.label";
	
	/** Left Hand-side Decomposition Label Key */
	public static final String LEFT_HAND_DECOMPOSITION_LABEL_KEY = "raven.label.leftHandDecomposition";
	
	/** Legend Label Key */
	public static final String LEGEND_LABEL_KEY = "raven.label.legend";
	
	/** Legend: In Both Interfaces Label Key */
	public static final String LEGEND_IN_BOTH_INTERFACES_LABEL_KEY = "raven.label.legendInBothInterfaces";
	
	/** Legend: Not In Interface Label Key */
	public static final String LEGEND_NOT_IN_INTERFACE_LABEL_KEY = "raven.label.legendNotInInterface";
	
	/** Legend: Only In Inner Interface Label Key */
	public static final String LEGEND_ONLY_IN_INNER_INTERFACE_LABEL_KEY = "raven.label.legendOnlyInInnerInterface";
	
	/** Legend: Only In Outer Interface Label Key */
	public static final String LEGEND_ONLY_IN_OUTER_INTERFACE_LABEL_KEY = "raven.label.legendOnlyInOuterInterface";
	
	/** Load Label Key */
	public static final String LOAD_LABEL_KEY = "raven.label.load";

	/** Mapping Bit Label Key */
	public static final String MAPPING_BIT_LABEL_KEY = "raven.label.mappingBit";
	
	/** Maximum Dominating Set Size Label Key */
	public static final String MAXIMUM_DOMINATING_SET_SIZE_LABEL_KEY = "raven.label.maximumDominatingSetSize";
	
	/** Maximum Interface Label Key */
	public static final String MAXIMUM_INTERFACE_LABEL_KEY = "raven.label.maximumInterface";
	
	/** Maximum Vertex Cover Size Label Key */
	public static final String MAXIMUM_VERTEX_COVER_SIZE_LABEL_KEY = "raven.label.maximumVertexCoverSize";

	/** Maximum Edge Label Key */
	public static final String MAXIMUM_EDGE_LABEL_KEY = "raven.label.maximumEdge";

	/** Maximum Vertex Label Key */
	public static final String MAXIMUM_VERTEX_LABEL_KEY = "raven.label.maximumVertex";

	/** Member Bit Label Key */
	public static final String MEMBER_BIT_LABEL_KEY = "raven.label.memberBit";
	
	/** Member Bits Label Key */
	public static final String MEMBER_BITS_LABEL_KEY = "raven.label.memberBits";
	
	/** Minimum Edge Label Key */
	public static final String MINIMUM_EDGE_LABEL_KEY = "raven.label.minimumEdge";

	/** Minimum Vertex Label Key */
	public static final String MINIMUM_VERTEX_LABEL_KEY = "raven.label.minimumVertex";

	/** Name Label Key */
	public static final String NAME_LABEL_KEY = "raven.label.name";	
	
	/** No Label Key */
	public static final String NO_LABEL_KEY = "raven.label.no";

	/** No Information Available Label Key */
	public static final String NO_INFORMATION_AVAILABLE_LABEL_KEY = "raven.label.noInformationAvailable";
	
	/** Node Label Key */
	public static final String NODE_LABEL_KEY = "raven.label.node";
	
	/** Node Number Label Key */
	public static final String NODE_NUMBER_LABEL_KEY = "raven.label.nodeNumber";
	
	/** Node Order Label Key */
	public static final String NODE_ORDER_LABEL_KEY = "raven.label.nodeOrder";
	
	/** Nodes Label Key */
	public static final String NODES_LABEL_KEY = "raven.label.nodes";
	
	/** None Label Key */
	public static final String NONE_LABEL_KEY = "raven.label.none";
	
	/** Number of BDD Nodes Label Key */
	public static final String NUMBER_OF_BDD_NODES_LABEL_KEY = "raven.label.numberOfBDDNodes";
	
	/** Number of Colors Label Key */
	public static final String NUMBER_OF_COLORS_LABEL_KEY = "raven.label.numberOfColors";
	
	/** Number of Edges Label Key */
	public static final String NUMBER_OF_EDGES_LABEL_KEY = "raven.label.numberOfEdges";
	
	/** Number of Final States Label Key */
	public static final String NUMBER_OF_FINAL_STATES_LABEL_KEY = "raven.label.numberOfFinalStates";
	
	/** Number of Initial States Label Key */
	public static final String NUMBER_OF_INITIAL_STATES_LABEL_KEY = "raven.label.numberOfInitialStates";
	
	/** Number of Nodes Label Key */
	public static final String NUMBER_OF_NODES_LABEL_KEY = "raven.label.numberOfNodes";
	
	/** Number of States Label Key */
	public static final String NUMBER_OF_STATES_LABEL_KEY = "raven.label.numberOfStates";
	
	/** Operations Label Key */
	public static final String OPERATIONS_LABEL_KEY = "raven.label.operations";

	/** Outer Interface Label Key */
	public static final String OUTER_INTERFACE_LABEL_KEY = "raven.label.outerInterface";
	
	/** Outer Interface Size Label Key */
	public static final String OUTER_INTERFACE_SIZE_LABEL_KEY = "raven.label.outerInterfaceSize";

	/** Output Label Key */
	public static final String OUTPUT_LABEL_KEY = "raven.label.output";
	
	/** Output Type Label Key */
	public static final String OUTPUT_TYPE_LABEL_KEY = "raven.label.outputtype";	

	/** Path Bit Label Key */
	public static final String PATH_BIT_LABEL_KEY = "raven.label.pathBit";
	
	/** Problem Label Key */
	public static final String PROBLEM_LABEL_KEY = "raven.label.problem";
	
	/** Quit Label Key */
	public static final String QUIT_LABEL_KEY = "raven.label.quit";
	
	/** Raven Script File Extension Key */
	public static final String RAVEN_SCRIPT_FILE_EXTENSION_KEY = "raven.label.ravenScriptFileExtension";
	
	/** Raven Script Files Label Key */
	public static final String RAVEN_SCRIPT_FILES_LABEL_KEY = "raven.label.ravenScriptFiles";
	
	/** */
	public static final String REPOSITORY_PANEL_LABEL = "raven.label.repositoryPanel";
	
	/** Ready for Computation Label Key */
	public static final String READY_FOR_COMPUTATION_LABEL_KEY = "raven.label.readyForComputation";

	/** Remainder Bit Label Key */
	public static final String REMAINDER_BIT_LABEL_KEY = "raven.label.remainderBit";

	/** Remainder Bits Label Key */
	public static final String REMAINDER_BITS_LABEL_KEY = "raven.label.remainderBits";
	
	/** Remainder Label Key */
	public static final String REMAINDER_EDGES_LABEL_KEY = "raven.label.remainderEdges";
	
	/** Remainder Label Key */
	public static final String REMAINDER_VERTICES_LABEL_KEY = "raven.label.remainderVertices";
	
	/** Remove Edge Label Key */
	public static final String REMOVE_EDGE_LABEL_KEY = "raven.label.removeEdge";
	
	/** Remove from Repository Label Key */
	public static final String REMOVE_FROM_REPOSITORY_LABEL_KEY = "raven.label.removeFromRepository";
	
	/** Remove Node Label Key */
	public static final String REMOVE_NODE_LABEL_KEY = "raven.label.removeNode";
	
	/** Right Hand-Side Decomposition Label Key */
	public static final String RIGHT_HAND_DECOMPOSITION_LABEL_KEY = "raven.label.rightHandDecomposition";
	
//	/** Run Label Key */
//	private static final String RUN_LABEL_KEY = "raven.label.run";
	
	/** Save Label Key */
	public static final String SAVE_LABEL_KEY = "raven.label.save";
	
	/** SearchType Label Key */
	public static final String SEARCHTYPE_LABEL_KEY = "raven.label.searchtype";
	
	/** Second Automaton Label Key */
	public static final String SECOND_AUTOMATON_LABEL_KEY = "raven.label.secondAutomaton";
	
	/** Shift-down Label Key */
	public static final String SHIFT_DOWN_LABEL_KEY = "raven.label.shiftDown";

	/** Shift-left Label Key */
	public static final String SHIFT_LEFT_LABEL_KEY = "raven.label.shiftLeft";

	/** Shift-right Label Key */
	public static final String SHIFT_RIGHT_LABEL_KEY = "raven.label.shiftRight";
	
	/** Shift-up Label Key */
	public static final String SHIFT_UP_LABEL_KEY = "raven.label.shiftUp";

	/** Show BDD Label Key */
	public static final String SHOW_BDD_LABEL_KEY = "raven.label.showBDD";
	
	/** Show Encoding Label Key */
	public static final String SHOW_ENCODING_LABEL_KEY = "raven.label.showEncoding";
	
	/** Show Run Label Key */
	public static final String SHOW_RUN_LABEL_KEY = "raven.label.showRun";
	
	/** Show Subgraph Label Key */
	public static final String SHOW_SUBGRAPH_LABEL_KEY = "raven.label.showSubgraph";
	
	/** Automaton Name Label Key */
	public static final String SIGNATURE_NAME_LABEL_KEY = "raven.label.signatureName";

	/** Signature File Extension Key */
	public static final String SIGNATURE_FILE_EXTENSION_KEY = "raven.label.signatureFileExtension";

	/** Signature Label Key */
	public static final String SIGNATURE_LABEL_KEY = "raven.label.signature";
	
	/** Size Bit Label Key */
	public static final String SIZE_BIT_LABEL_KEY = "raven.label.sizeBit";
	
	/** Source Nodes Label Key */
	public static final String SOURCE_NODES_LABEL_KEY = "raven.label.sourceNodes";

	/** Source Path Bit Label Key */
	public static final String SOURCE_PATH_BIT_LABEL_KEY = "raven.label.sourcePathBit";

	/** Source Path Bits Label Key */
	public static final String SOURCE_PATH_BITS_LABEL_KEY = "raven.label.sourcePathBits";
	
	/** Subgraph Label Key */
	public static final String SUBGRAPH_LABEL_KEY = "raven.label.subgraph";
	
	/** Successor Label Key*/
	public static final String SUCCESSOR_INTERFACE_LABEL_KEY = "raven.label.successorInterface";
	
	/** SVG File Extension Label Key */
	public static final String SVG_FILE_EXTENSION_LABEL_KEY = "raven.label.svgFileExtension";
	
	/** Target Nodes Label Key */
	public static final String TARGET_NODES_LABEL_KEY = "raven.label.targetNodes";
	
	/** Technique Panel Label Key */
	public static final String TECHNIQUE_PANEL_LABEL = "raven.label.techniquePanel";

	/** Type Label Key */
	public static final String TYPE_LABEL_KEY = "raven.label.type";
	
	/** Update Information Label Key */
	public static final String UPDATE_INFORMATION_LABEL_KEY = "raven.label.updateInformation";
	
	/** Subgraph Label Key */
	public static final String UNION_LABEL_KEY = "raven.label.union";
	
	/** Value Label Key */
	public static final String VALUE_LABEL_KEY = "raven.label.value";
	
	/** Vertex Label Key */
	public static final String VERTEX_LABEL_KEY = "raven.label.vertex";

	/** Vertex Bit Label Key */
	public static final String VERTEX_BIT_LABEL_KEY = "raven.label.vertexBit";
	
	/** Yes Label Key */
	public static final String YES_LABEL_KEY = "raven.label.yes";
	
	
	/* Action Keys */
	/** Save Automaton Action Key */
	public static final String SAVE_AUTOMATON_ACTION_KEY = "raven.action.save.automaton";
	
	/** Save Cospan Action Key */
	public static final String SAVE_COSPAN_ACTION_KEY = "raven.action.save.cospan";
	
	/** Save Graph Action Key */
	public static final String SAVE_GRAPH_ACTION_KEY = "raven.action.save.graph";
	
	/** Save Signature Action Key */
	public static final String SAVE_SIGNATURE_ACTION_KEY = "raven.action.save.signature";
	
	/** Save Decomposition Action Key */
	public static final String SAVE_DECOMPOSITION_ACTION_KEY = "raven.action.save.decomposition";

	
	/* Dialog Keys */
	/** */
	public static final String AUTOMATON_CREATION_DIALOG_TITLE_KEY = "raven.dialog.automatonCreation.title";

	/** */
	public static final String AUTOMATON_CREATION_AUTOMATON_PROPERTIES_TEXT_KEY = "raven.dialog.automatonCreation.automatonProperties";

	/** */
	public static final String AUTOMATON_CREATION_ADVANCED_PROPERTIES_TEXT_KEY = "raven.dialog.automatonCreation.advancedProperties";

	/** */
	public static final String AUTOMATON_CREATION_PROPERTIES_TEXT_KEY = "raven.dialog.automatonCreation.generalProperties";
	
	/** */
	public static final String AUTOMATON_LOAD_DIALOG_TITLE_KEY = "raven.dialog.automatonLoad.title";

	/** */
	public static final String AUTOMATON_RUN_DIALOG_TITLE_KEY = "raven.dialog.automatonRun.title";
	
	/** */
	public static final String AUTOMATON_SAVE_DIALOG_TITLE_KEY = "raven.dialog.automatonSave.title";
	
	/** */
	public static final String AUTOMATON_SAVED_TEXT_KEY = "raven.dialog.automatonSaved.text";
	
	/** */
	public static final String AUTOMATON_SAVED_TITLE_KEY = "raven.dialog.automatonSaved.title";
	
	/** */
	public static final String BDD_DIALOG_TITLE_KEY = "raven.dialog.bddDialog.title";

	/** */
	public static final String COSPAN_CREATION_DIALOG_TITLE_KEY = "raven.dialog.cospanCreation.title";
	
	/** */
	public static final String COSPAN_SAVE_DIALOG_TITLE_KEY = "raven.dialog.cospanSave.title";
	
	/** */
	public static final String COSPAN_SAVED_TEXT_KEY = "raven.dialog.cospanSaved.text";

	/** */
	public static final String COSPAN_SAVED_TITLE_KEY = "raven.dialog.cospanSaved.title";
	
	/** Create Random Graph Dialog Text Key */
	public static final String CREATE_RANDOM_GRAPH_DIALOG_TEXT_KEY = "raven.dialog.createRandomGraph.text";
	
	/** Create Random Graph Dialog Title Key */
	public static final String CREATE_RANDOM_GRAPH_DIALOG_TITLE_KEY = "raven.dialog.createRandomGraph.title";
	
	/** */
	public static final String DECOMPOSTION_ADDED_DIALOG_TEXT_KEY = "raven.dialog.decompositionAdded.text";
	
	/** */
	public static final String DECOMPOSTION_ADDED_DIALOG_TITLE_KEY = "raven.dialog.decompositionAdded.title";
	
	/** */
	public static final String DECOMPOSITION_CREATION_DIALOG_TITLE_KEY = "raven.dialog.decompositionCreation.title";
	
	/** */
	public static final String DECOMPOSITION_LOAD_DIALOG_TITLE_KEY = "raven.dialog.decompositionLoad.title";
	
	/** */
	public static final String DECOMPOSITION_SAVE_DIALOG_TITLE_KEY = "raven.dialog.decompositionSave.title";
	
	/** */
	public static final String DECOMPOSITION_SAVED_TEXT_KEY = "raven.dialog.decompositionSaved.text";
	
	/** */
	public static final String DECOMPOSITION_SAVED_TITLE_KEY = "raven.dialog.decompositionSaved.title";
	
	/** */
	public static final String DELETE_FORBIDDEN_TEXT_KEY = "raven.dialog.deleteForbidden.text";

	/** */
	public static final String DELETE_FORBIDDEN_TITLE_KEY = "raven.dialog.deleteForbidden.title";

	/** */
	public static final String EMPTINESS_DOES_HOLD_DIALOG_TEXT_KEY = "raven.dialog.emptinessDoesHold.text";

	/** */
	public static final String EMPTINESS_DOES_HOLD_DIALOG_TITLE_KEY = "raven.dialog.emptinessDoesHold.title";

	/** */
	public static final String EMPTINESS_DOES_NOT_HOLD_DIALOG_TEXT_KEY = "raven.dialog.emptinessDoesNotHold.text";
	
	/** */
	public static final String EMPTINESS_DOES_NOT_HOLD_DIALOG_TITLE_KEY = "raven.dialog.emptinessDoesNotHold.title";

	/** */
	public static final String FILE_ALREADY_EXISTING_TEXT_KEY = "raven.dialog.fileAlreadyExisting.text";
	
	/** */
	public static final String FILE_ALREADY_EXISTING_TITLE_KEY = "raven.dialog.fileAlreadyExisting.title";

	/** */
	public static final String GRAPH_CREATION_DIALOG_TITLE_KEY = "raven.dialog.graphCreation.title";

	/** */
	public static final String GRAPH_SAVE_DIALOG_TITLE_KEY = "raven.dialog.graphSave.title";
	
	/** */
	public static final String GRAPH_SAVED_TEXT_KEY = "raven.dialog.graphSaved.text";

	/** */
	public static final String GRAPH_SAVED_TITLE_KEY = "raven.dialog.graphSaved.title";
	
	/** */
	public static final String INNER_INTERFACE_SIZE_SELECTION_TITLE_KEY = "raven.dialog.innerInterfaceSizeSelection.title";
	
	/** */
	public static final String IS_INVARIANT_DIALOG_TEXT_KEY = "raven.dialog.isInvariant.text";

	/** */
	public static final String IS_INVARIANT_DIALOG_TITLE_KEY = "raven.dialog.isInvariant.title";
	
	/** */
	public static final String IS_NOT_INVARIANT_DIALOG_TEXT_KEY = "raven.dialog.isNotInvariant.text";
	
	/** */
	public static final String IS_NOT_INVARIANT_DIALOG_TITLE_KEY = "raven.dialog.isNotInvariant.title";

	/** */
	public static final String LOAD_COSPAN_DIALOG_TITLE_KEY = "raven.dialog.loadCospan.title";
	
	/** */
	public static final String LOAD_DECOMPOSITION_DIALOG_TITLE_KEY = "raven.dialog.loadDecomposition.title";
	
	/** */
	public static final String LOAD_GRAPH_DIALOG_TITLE_KEY = "raven.dialog.loadGraph.title";
	
	/** */
	public static final String LANGUAGE_INCLUSION_DOES_HOLD_DIALOG_TEXT_KEY = "raven.dialog.languageInclusionDoesHold.text";
	
	/** */
	public static final String LANGUAGE_INCLUSION_DOES_HOLD_DIALOG_TITLE_KEY = "raven.dialog.languageInclusionDoesHold.title";
	
	/** */
	public static final String LANGUAGE_INCLUSION_DOES_NOT_HOLD_DIALOG_TEXT_KEY = "raven.dialog.languageInclusionDoesNotHold.text";
	
	/** */
	public static final String LANGUAGE_INCLUSION_DOES_NOT_HOLD_DIALOG_TITLE_KEY = "raven.dialog.languageInclusionDoesNotHold.title";
	
	/** */
	public static final String MEMBERSHIP_DOES_HOLD_DIALOG_TEXT_KEY = "raven.dialog.membershipDoesHold.text";

	/** */
	public static final String MEMBERSHIP_DOES_HOLD_DIALOG_TITLE_KEY = "raven.dialog.membershipDoesHold.title";
	
	/** */
	public static final String MEMBERSHIP_DOES_NOT_HOLD_DIALOG_TEXT_KEY = "raven.dialog.membershipDoesNotHold.text";

	/** */
	public static final String MEMBERSHIP_DOES_NOT_HOLD_DIALOG_TITLE_KEY = "raven.dialog.membershipDoesNotHold.title";
	
	/** */
	public static final String NEW_EDGE_DIALOG_TITLE_KEY = "raven.dialog.newEdge.title";
	
	/** */
	public static final String NEW_LABEL_DIALOG_TITLE_KEY = "raven.dialog.newLabel.title";
	
	/** */
	public static final String NEW_EDGE_DIALOG_NO_SELECTION_TEXT_KEY = "raven.dialog.newEdgeNoSelection.text";
	
	/** */
	public static final String NEW_EDGE_DIALOG_NO_SELECTION_TITLE_KEY = "raven.dialog.newEdgeNoSelection.title";

	/** No Help Available Dialog Text Key */
	public static final String NO_HELP_AVAILABLE_TEXT_KEY = "raven.dialog.help.notAvailable.text";

	/** No Help Available Dialog Title Key */
	public static final String NO_HELP_AVAILABLE_TITLE_KEY = "raven.dialog.help.notAvailable.title";
	
	/** */
	public static final String NO_KEY_SELECTED_TEXT_KEY = "raven.dialog.noKeySelected.text";
	
	/** */
	public static final String NO_KEY_SELECTED_TITLE_KEY = "raven.dialog.noKeySelected.title";
	
	/** */
	public static final String NO_OPERATION_SELECTED_TEXT_KEY = "raven.dialog.noOperationSelected.text";
	
	/** */
	public static final String NO_OPERATION_SELECTED_TITLE_KEY = "raven.dialog.noOperationSelected.title";
	
	/** No Update Available Dialog Text Key */
	public static final String NO_UPDATE_AVAILABLE_TEXT_KEY = "raven.dialog.update.notAvailable.text";

	/** No Update Available Dialog Title Key */
	public static final String NO_UPDATE_AVAILABLE_TITLE_KEY = "raven.dialog.update.notAvailable.title";
	
	/** Properties Dialog Title Key */
	public static final String PROPERTIES_DIALOG_TITLE_KEY = "raven.dialog.propertyDialog.title";
	
	/** */
	public static final String SIGNATURE_CREATION_DIALOG_TITLE_KEY = "raven.dialog.signatureCreation.title";
	
	/** */
	public static final String SIGNATURE_SAVE_DIALOG_TITLE_KEY = "raven.dialog.signatureSave.title";
	
	/** */
	public static final String SIGNATURE_SAVED_TEXT_KEY = "raven.dialog.signatureSaved.text";
	
	/** */
	public static final String SIGNATURE_SAVED_TITLE_KEY = "raven.dialog.signatureSaved.title";
	
	/** */
	public static final String SIGNATURE_SELECTION_TITLE_KEY = "raven.dialog.signatureSelection.title";
	
	/** */
	public static final String SIGNATURE_LOAD_DIALOG_TITLE_KEY = "raven.dialog.signatureLoad.title";
	
	/** */
	public static final String SIMULATION_CREATED_TEXT_KEY = "raven.dialog.simulationCreated.text";
	
	/** */
	public static final String SIMULATION_NOT_CREATED_TEXT_KEY = "raven.dialog.simulationNotCreated.text";

	/** */
	public static final String UNIVERSALITY_DOES_HOLD_DIALOG_TEXT_KEY = "raven.dialog.universalityDoesHold.text";

	/** */
	public static final String UNIVERSALITY_DOES_HOLD_DIALOG_TITLE_KEY = "raven.dialog.universalityDoesHold.title";

	/** */
	public static final String UNIVERSALITY_DOES_NOT_HOLD_DIALOG_TEXT_KEY = "raven.dialog.universalityDoesNotHold.text";
	
	/** */
	public static final String UNIVERSALITY_DOES_NOT_HOLD_DIALOG_TITLE_KEY = "raven.dialog.universalityDoesNotHold.title";
	
	/** Update Available Dialog Text Key */
	public static final String UPDATE_AVAILABLE_TEXT_KEY = "raven.dialog.update.updateNow.text";
	
	/** Update Available Dialog Title Key */
	public static final String UPDATE_AVAILABLE_TITLE_KEY = "raven.dialog.update.updateNow.title";
	
	/** */
	public static final String UPDATE_PROPERTY_DIALOG_TITLE_KEY = "raven.dialog.updateProperty.title";
	
	
	/* Exception Keys */
//	private static final String EXCEPTION_OCCURED_KEY = null;
//	private static final String EMPTY_STRING_KEY = "raven.exception.emptyString";
//	private static final String NULL_POINTER_KEY = "raven.exception.nullPointer";
	
	/** */
	public static final String ALPHABETS_MUST_BE_EQUAL_TEXT_EXCEPTION_KEY = "raven.exception.alphabetsMustBeEqual.text";
	
	/** */
	public static final String ALPHABETS_MUST_BE_EQUAL_TITLE_EXCEPTION_KEY = "raven.exception.alphabetsMustBeEqual.title";
	
	/** */
	public static final String ALREADY_IN_REPOSITORY_TEXT_EXCEPTION_KEY = "raven.exception.AlreadyInRepository.text";

	/** */
	public static final String AUTOMATA_MUST_NOT_BE_EQUAL_TEXT_EXCEPTION_KEY = "raven.exception.automataMustNotBeEqual.text";
	
	/** */
	public static final String AUTOMATA_MUST_NOT_BE_EQUAL_TITLE_EXCEPTION_KEY = "raven.exception.automataMustNotBeEqual.title";

	/** */
	public static final String DATA_NOT_FOUND_TEXT_EXCEPTION_KEY = "raven.exception.dataNotFound.text";
	
	/** */
	public static final String DATA_NOT_FOUND_TITLE_EXCEPTION_KEY = "raven.exception.dataNotFound.title";

	/** Dot-Error Occurred Exception Text Key*/
	public static final String DOT_ERROR_OCCURRED_TEXT_EXCEPTION_KEY = "raven.exception.dotErrorOccurred.text";
	
	/** Dot-Error Occurred Exception Title Key*/
	public static final String DOT_ERROR_OCCURRED_TITLE_EXCEPTION_KEY = "raven.exception.dotErrorOccurred.title";

	/** Dot-Executable Not Found Exception Text Key*/
	public static final String DOT_PATH_NOT_FOUND_TEXT_EXCEPTION_KEY = "raven.exception.dotPathNotFound.text";
	
	/** Dot-Executable Not Found Exception Title Key*/
	public static final String DOT_PATH_NOT_FOUND_TITLE_EXCEPTION_KEY = "raven.exception.dotPathNotFound.title";
	
	/** */
	public static final String EMPTY_FILENAME_TEXT_EXCEPTION_KEY = "raven.exception.emptyFilename.text";
	
	/** */
	public static final String EMPTY_FILENAME_TITLE_EXCEPTION_KEY = "raven.exception.emptyFilename.title";
	
	/** */
	public static final String EMPTY_INPUTFIELD_TEXT_EXCEPTION_KEY = "raven.exception.emptyInputField.text";
	
	/** */
	public static final String EMPTY_INPUTFIELD_TITLE_EXCEPTION_KEY = "raven.exception.emptyInputField.title";
	
	/** */
	public static final String EMPTY_LIST_TITLE_EXCEPTION_KEY = "raven.exception.emptyList.title";
	
	/** */
	public static final String EMPTY_LIST_TEXT_EXCEPTION_KEY = "raven.exception.emptyList.text";

	/** */
	public static final String EMPTY_NAME_TEXT_EXCEPTION_KEY = "raven.exception.emptyName.text";
	
	/** */
	public static final String EMPTY_NAME_TITLE_EXCEPTION_KEY = "raven.exception.emptyName.title";
	
	/** */
	public static final String EXISTING_EDGE_NAME_TEXT_EXCEPTION_KEY = "raven.exception.existingEdgeName.text";
	
	/** */
	public static final String EXISTING_EDGE_NAME_TITLE_EXCEPTION_KEY = "raven.exception.existingEdgeName.title";
	
	/** File Can Not Be Opened Exception Text Key */
	public static final String FILE_CAN_NOT_BE_OPENED_TEXT_EXCEPTION_KEY = "raven.exception.fileCanNotBeOpened.text";
	
	/** File Can Not Be Opened Exception Title Key */
	public static final String FILE_CAN_NOT_BE_OPENED_TITLE_EXCEPTION_KEY = "raven.exception.fileCanNotBeOpened.title";
	
	/** File Not Found Exception Text Key */
	public static final String FILE_NOT_FOUND_TEXT_EXCEPTION_KEY = "raven.exception.fileNotFound.text";
	
	/** File Not Found Exception Title Key */
	public static final String FILE_NOT_FOUND_TITLE_EXCEPTION_KEY = "raven.exception.fileNotFound.title";
	
	/** */
	public static final String INNER_INTERFACE_SIZES_MUST_BE_EQUAL_TEXT_EXCEPTION_KEY = "raven.exception.innerInterfacesMustBeEqual.text";
	
	/** */
	public static final String INNER_INTERFACE_SIZES_MUST_BE_EQUAL_TITLE_EXCEPTION_KEY = "raven.exception.innerInterfacesMustBeEqual.title";
	
	/** */
	public static final String INPUT_MISSING_TEXT_EXCEPTION_KEY = "raven.exception.inputMissing.text";
	
	/** */
	public static final String INPUT_MISSING_TITLE_EXCEPTION_KEY = "raven.exception.inputMissing.title";
	
	/** IO-Exception Occurred Exception Text Key*/
	public static final String IO_EXCEPTION_TEXT_EXCEPTION_KEY = "raven.exception.ioExceptionOccurred.text";
	
	/** IO-Exception Occurred Exception Title Key*/
	public static final String IO_EXCEPTION_TITLE_EXCEPTION_KEY = "raven.exception.ioExceptionOccurred.title";
	
	/** */
	public static final String MAXIMUM_INTERFACE_SIZES_MUST_BE_EQUAL_TEXT_EXCEPTION_KEY = "raven.exception.maximumInterfacesMustBeEqual.text";
	
	/** */
	public static final String MAXIMUM_INTERFACE_SIZES_MUST_BE_EQUAL_TITLE_EXCEPTION_KEY = "raven.exception.maximumInterfacesMustBeEqual.title";

	/** Invalid Input Exception Text Key */
	public static final String INVALID_INPUT_TEXT_EXCEPTION_KEY = "raven.exception.invalidInput.text";
	
	/** Invalid Input Exception Title Key */
	public static final String INVALID_INPUT_TITLE_EXCEPTION_KEY = "raven.exception.invalidInput.title";
	
	/** */
	public static final String INVALID_LABEL_TEXT_EXCEPTION_KEY = "raven.exception.invalidLabel.text";
	
	/** */
	public static final String INVALID_LABEL_TITLE_EXCEPTION_KEY = "raven.exception.invalidLabel.title";
	
	/** */
	public static final String INVALID_LABEL_ARITY_TEXT_EXCEPTION_KEY = "raven.exception.invalidLabelArity.text";
	
	/** */
	public static final String INVALID_LABEL_ARITY_TITLE_EXCEPTION_KEY = "raven.exception.invalidLabelArity.title";
	
	/** */
	public static final String INVALID_NAME_TEXT_EXCEPTION_KEY = "raven.exception.invalidName.text";
	
	/** */
	public static final String INVALID_NAME_TITLE_EXCEPTION_KEY = "raven.exception.invalidName.title";
	
	/** */
	public static final String INVALID_NUMBER_TEXT_EXCEPTION_KEY = "raven.exception.invalidNumber.text";
	
	/** */
	public static final String INVALID_NUMBER_TITLE_EXCEPTION_KEY = "raven.exception.invalidNumber.title";
	
	/** */
	public static final String NAME_ALREADY_IN_USE_TEXT_EXCEPTION_KEY = "raven.exception.nameAlreadyInUse.title";
	
	/** */
	public static final String NAME_ALREADY_IN_USE_TITLE_EXCEPTION_KEY = "raven.exception.nameAlreadyInUse.title";
	
	/** */
	public static final String NAME_INVALID_EXCEPTION_KEY = "raven.exception.nameInvalid.text";
	
	/** */
	public static final String NO_AUTOMATON_FILE_SELECTED_TEXT_EXCEPTION_KEY = "raven.exception.noAutomatonFileSelected.text";
	
	/** */
	public static final String NO_AUTOMATON_FILE_SELECTED_TITLE_EXCEPTION_KEY = "raven.exception.noAutomatonFileSelected.title";
	
	/** */
	public static final String NO_AUTOMATON_SELECTED_TEXT_EXCEPTION_KEY = "raven.exception.noAutomatonSelected.text";
	
	/** */
	public static final String NO_AUTOMATON_SELECTED_TITLE_EXCEPTION_KEY = "raven.exception.noAutomatonSelected.title";

	/** */
	public static final String NO_COSPAN_FILE_SELECTED_TEXT_EXCEPTION_KEY = "raven.exception.noCospanFileSelected.text";
	
	/** */
	public static final String NO_COSPAN_FILE_SELECTED_TITLE_EXCEPTION_KEY = "raven.exception.noCospanFileSelected.title";

	/** */
	public static final String NO_COSPAN_SELECTED_TEXT_EXCEPTION_KEY = "raven.exception.noCospanSelected.text";
	
	/** */
	public static final String NO_COSPAN_SELECTED_TITLE_EXCEPTION_KEY = "raven.exception.noCospanSelected.title";
	
	/** */
	public static final String NO_DECOMPOSITION_FILE_SELECTED_TEXT_EXCEPTION_KEY = "raven.exception.noDecompositionFileSelected.text";
	
	/** */
	public static final String NO_DECOMPOSITION_FILE_SELECTED_TITLE_EXCEPTION_KEY = "raven.exception.noDecompositionFileSelected.title";
	
	/** */
	public static final String NO_DECOMPOSITION_SELECTED_TEXT_EXCEPTION_KEY = "raven.exception.noDecompositionSelected.text";
	
	/** */
	public static final String NO_DECOMPOSITION_SELECTED_TITLE_EXCEPTION_KEY = "raven.exception.noDecompositionSelected.title";
	
	/** No Edge Selected Exception Text Key */
	public static final String NO_EDGE_SELECTED_TEXT_EXCEPTION_KEY = "raven.exception.noEdgeSelected.text";
	
	/** No Edge Selected Exception Title Key */
	public static final String NO_EDGE_SELECTED_TITLE_EXCEPTION_KEY = "raven.exception.noEdgeSelected.title";
	
	/** */
	public static final String NO_GRAPH_FILE_SELECTED_TEXT_EXCEPTION_KEY = "raven.exception.noGraphFileSelected.text";
	
	/** */
	public static final String NO_GRAPH_FILE_SELECTED_TITLE_EXCEPTION_KEY = "raven.exception.noGraphFileSelected.title";

	/** */
	public static final String NO_GRAPH_SELECTED_TEXT_EXCEPTION_KEY = "raven.exception.noGraphSelected.text";
	
	/** */
	public static final String NO_GRAPH_SELECTED_TITLE_EXCEPTION_KEY = "raven.exception.noGraphSelected.title";
	
	/** */
	public static final String NO_LOOP_GRAPH_TEXT_EXCEPTION_KEY = "raven.exception.noLoopGraph.text";
	
	/** */
	public static final String NO_LOOP_GRAPH_TITLE_EXCEPTION_KEY = "raven.exception.noLoopGraph.title";
	
	/** */
	public static final String NO_GXL_CHOSEN_TEXT_EXCEPTION_KEY = "raven.exception.noGxlSelected.text";
	
	/** No Node Selected Exception Text Key */
	public static final String NO_NODE_SELECTED_TEXT_EXCEPTION_KEY = "raven.exception.noNodeSelected.text";
	
	/** No Node Selected Exception Title Key */
	public static final String NO_NODE_SELECTED_TITLE_EXCEPTION_KEY = "raven.exception.noNodeSelected.title";
	
	/** */
	public static final String NO_OPERATION_SELECTED_TEXT_EXCEPTION_KEY = "raven.exception.noOperationSelected.text";
	
	/** */
	public static final String NO_OPERATION_SELECTED_TITLE_EXCEPTION_KEY = "raven.exception.noOperationSelected.title";
	
	/** */
	public static final String NO_SIGNATURE_AVAILABLE_TEXT_EXCEPTION_KEY = "raven.exception.noSignatureAvailable.text";
	
	/** */
	public static final String NO_SIGNATURE_AVAILABLE_TITLE_EXCEPTION_KEY = "raven.exception.noSignatureAvailable.title";
	
	/** */
	public static final String NO_SIGNATURE_SELECTED_TEXT_EXCEPTION_KEY = "raven.exception.noSignatureSelected.text";

	/** */
	public static final String NO_SIGNATURE_SELECTED_TITLE_EXCEPTION_KEY = "raven.exception.noSignatureSelected.title";
	
	/** */
	public static final String NO_SIGNATURE_USED_TEXT_EXCEPTION_KEY = "raven.exception.noSignatureUsed.text";

	/** */
	public static final String NO_SIGNATURE_USED_TITLE_EXCEPTION_KEY = "raven.exception.noSignatureUsed.title";
	
	/** */
	public static final String NO_SIGNATURE_FILE_SELECTED_TEXT_EXCEPTION_KEY = "raven.exception.noSignatureFileSelected.text";

	/** */
	public static final String NO_SIGNATURE_FILE_SELECTED_TITLE_EXCEPTION_KEY = "raven.exception.noSignatureFileSelected.title";
	
	/** */
	public static final String OPERATION_NOT_APPLICABLE_TEXT_EXCEPTION_KEY = "raven.exception.operationNotApplicable.text";
	
	/** */
	public static final String OPERATION_NOT_APPLICABLE_TITLE_EXCEPTION_KEY = "raven.exception.operationNotApplicable.title";
	
	/** */
	public static final String OUTER_INTERFACE_SIZES_MUST_BE_EQUAL_TEXT_EXCEPTION_KEY = "raven.exception.outerInterfacesMustBeEqual.text";
	
	/** */
	public static final String OUTER_INTERFACE_SIZES_MUST_BE_EQUAL_TITLE_EXCEPTION_KEY = "raven.exception.outerInterfacesMustBeEqual.title";
	
	/** */
	public static final String RENAME_NOT_SUCCESSFULL_TEXT_EXCEPTION_KEY = "raven.exception.renameNotSuccessfull.text";
	
	/** */
	public static final String RENAME_NOT_SUCCESSFULL_TITLE_EXCEPTION_KEY = "raven.exception.renameNotSuccessfull.title";
	
	/** Update Error Exception Text Key */
	public static final String UPDATE_ERROR_TEXT_EXCEPTION_KEY = "raven.exception.updateError.text";
	
	/** Update Error Exception Title Key */
	public static final String UPDATE_ERROR_TITLE_EXCEPTION_KEY = "raven.exception.updateError.title";
	
	/** */
	public static final String VALUE_GREATER_THAN_TEXT_EXCEPTION_KEY = "raven.exception.valueGreaterThan.text";
	
	/** */
	public static final String VALUE_GREATER_THAN_TITLE_EXCEPTION_KEY = "raven.exception.valueGreaterThan.title";
	
	/** Only Non-Negative Value Permitted Exception Text Key */
	public static final String VALUE_MUST_BE_NON_NEGATIVE_TEXT_EXCEPTION_KEY = "raven.exception.noNegativeValue.text";
	
	/** Only Non-Negative Value Permitted Exception Title Key */
	public static final String VALUE_MUST_BE_NON_NEGATIVE_TITLE_EXCEPTION_KEY = "raven.exception.noNegativeValue.title";
	
	/** */
	public static final String VALUE_MUST_BE_POSITIVE_TEXT_EXCEPTION_KEY = "raven.exception.noNonPositiveValue.text";
	
	/** */
	public static final String VALUE_MUST_BE_POSITIVE_TITLE_EXCEPTION_KEY = "raven.exception.noNonPositiveValue.title";
	
	
	/* Message Keys */
	/** */
	public static final String AUTOMATON_ADDED_MESSAGE_KEY = "raven.message.automatonAdded";

	/** */
	public static final String COSPAN_ADDED_MESSAGE_KEY = "raven.message.cospanAdded";

	/** */
	public static final String DATA_REMOVED_MESSAGE_KEY = "raven.message.dataRemoved";
	
	/** */
	public static final String DECOMPOSITION_ADDED_MESSAGE_KEY = "raven.message.decompositionAdded";
	
	/** */
	public static final String GRAPH_ADDED_MESSAGE_KEY = "raven.message.graphAdded";
	
	/** */
	public static final String SIGNATURE_ADDED_MESSAGE_KEY = "raven.message.signatureAdded";

	/** */
	public static final String UNKNOWN_DATA_ADDED_MESSAGE_KEY = "raven.message.unknownDataAdded";
	
	
	//Message Bundle Name
	private static final String BUNDLE_NAME = "de.uni_due.inf.ti.raven.messages.raven-gui-messages";

	private static GuiMessages guiMessages;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Static Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Returns the GUI message bundle.
	 * @return the gui messages
	 */
	public static GuiMessages getMessages() {
		if(guiMessages==null) {
			guiMessages = new GuiMessages();
		}
		
		return guiMessages;
	}
		
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates the GUI message bundle.
	 */
	private GuiMessages() {
		super(BUNDLE_NAME);
	}
	
}
