/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.gui;

import javax.swing.JTextField;

import com.jgoodies.forms.builder.DefaultFormBuilder;
import com.jgoodies.forms.layout.FormLayout;

import de.uni_due.inf.ti.raven.data.PathDecomposition;
import de.uni_due.inf.ti.raven.data.Repository;

/**
 * This class provides a builder which is used to  create an {@code InformationPanel} 
 * for displaying information about <i>path decompositions</i>.
 * @author Christoph Blume, Laura Steinert
 * @version $Revision: 1.4 $
 *
 * @see PathDecomposition
 */
public final class PathDecompositionInformationPanelBuilder extends InformationPanelBuilder<PathDecomposition> {

	/**
	 * 
	 * @author Christoph Blume
	 *
	 */
	private static class PathDecompositionInformationPanel extends InformationPanel<PathDecomposition> {

		private static final long serialVersionUID = -1821154740159142849L;

		private static final Repository repo = Repository.getRepository();

		/*------------------------------------------------------------------------------------------*/
		/* 		Public Methods																		*/
		/*------------------------------------------------------------------------------------------*/


		@Override
		public void setData(PathDecomposition data) {
			decompNameField.setText(repo.getName(data));		
		}

	}

	private static PathDecompositionInformationPanelBuilder panelBuilder;
	private static InformationPanel<PathDecomposition> panel;
	private static JTextField decompNameField;

	/*------------------------------------------------------------------------------------------*/
	/*		Static Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates an information panel displaying properties of a given path decomposition.
	 * @return the path decomposition information panel
	 */
	public static InformationPanel<PathDecomposition> createPanel() {
		if(panelBuilder==null) {
			panel = new PathDecompositionInformationPanel();
			DefaultFormBuilder builder = new DefaultFormBuilder(
					new FormLayout(LAYOUT_SPECIFICATION), panel);
			panelBuilder = new PathDecompositionInformationPanelBuilder(builder);
		}
		
		return panel;
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/

	/**
	 * Creates the panel on which graph information will be displayed.
	 * @param formBuilder the form builder used to build the panel
	 */
	public PathDecompositionInformationPanelBuilder(DefaultFormBuilder formBuilder) {
		super(formBuilder);

		decompNameField = new JTextField(10);
		decompNameField.setEditable(false);
		formBuilder.append(GuiMessages.NAME_LABEL_KEY, decompNameField);

	}

}
