/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.gui;

import java.io.File;
import java.io.IOException;
import java.text.MessageFormat;

import javax.swing.UIManager;
import javax.swing.filechooser.FileSystemView;

/**
 * This class provides a {@code FileSystemView} which is able to create new folders.
 * @author Christoph Blume
 * @version $Revision: 1.4 $
 *
 */
public class RavenDirectoryFileSystemView extends FileSystemView {
	
	private final String NEW_FOLDER_STRING = UIManager.getString("FileChooser.other.newFolder");
	private final String NEW_FOLDER_NEXT_STRING = UIManager.getString(
			"FileChooser.other.newFolder.subsequent");
	
	private File root;
	private File defaultDirectory;
	private File[] roots;

	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/

	/**
	 * Creates a new {@code FileSystemView} with the directory given by {@code rootDirectory} as
	 * root directory and {@code defaultDirectory} as default directory.
	 * @param rootDirectory the root directory
	 * @param defaultDirectory the default directory
	 */ 
	public RavenDirectoryFileSystemView(File rootDirectory, File defaultDirectory) {
		super();
		this.root = rootDirectory;
		this.defaultDirectory = defaultDirectory;
		roots = new File[]{ this.root };
	}
	
	/*------------------------------------------------------------------------------------------*/
	/* 		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/

	@Override
	public File createNewFolder(File containingDir) throws IOException {
		 if(containingDir == null) {
			 throw new IOException("Containing directory is null:");
		 }

		 File newFolder = null;
		 // Unix - using OpenWindows' default folder name. Can't find one for Motif/CDE.
		 newFolder = createFileObject(containingDir, NEW_FOLDER_STRING);
		 int i = 1;
		 while (newFolder.exists() && (i < 100)) {
			 newFolder = createFileObject(containingDir, MessageFormat.format(
					 NEW_FOLDER_NEXT_STRING, new Object[] { new Integer(i) }));
			 i++;
		}
		 
		if(newFolder.exists()) {
			 throw new IOException("Directory already exists:" + newFolder.getAbsolutePath());
		}
		
		newFolder.mkdirs();
		return newFolder;
	}

	@Override
	public File getDefaultDirectory() {
		return defaultDirectory;
	}

	@Override
	public File getHomeDirectory() {
		return root;
	}

	@Override
	public File[] getRoots() {
		return roots;
	}
    
}
