/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
*/

package de.uni_due.inf.ti.raven.gui;

import java.awt.FlowLayout;

import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JProgressBar;

import de.uni_due.inf.ti.raven.actions.ComputationEvent;
import de.uni_due.inf.ti.raven.actions.ComputationEvent.EventType;
import de.uni_due.inf.ti.raven.actions.ComputationListener;

/**
 * This class provides a panel to create a progress bar with an additional label.
 * 
 * @author Christoph Blume, Dennis Nolte
 * @version $Revision: 1.9 $
 * 
 */

public final class RavenProgressBarPanel extends JPanel implements ComputationListener {

	private static final long serialVersionUID = -8692373390865020836L;
	
	private static final GuiMessages messages = GuiMessages.getMessages();
	
	private JProgressBar bar;
	private JLabel label;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates a new progress bar panel.
	 */
	public RavenProgressBarPanel() {
		super(new FlowLayout(FlowLayout.LEFT));

		setOpaque(false);
		bar = new JProgressBar(0,100);
		bar.setStringPainted(true);
		bar.setString("0%\r");
		bar.setOpaque(false);
		
		label = new JLabel(messages.getString(GuiMessages.READY_FOR_COMPUTATION_LABEL_KEY));
		label.setOpaque(false);

		add(bar);
		add(label);
		setOpaque(false);
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	@Override
	public void computationAdvanded(ComputationEvent e) {
		
		if(e.getMaximum() != 0) {
			bar.setMaximum(e.getMaximum());
			bar.setValue(e.getValue());		
			bar.setString(String.format("%3.2f", ((float) e.getValue()/(float) e.getMaximum() *100))+"%\r");		
			label.setText(messages.getString(GuiMessages.COMPUTING_LABEL_KEY, e.getName()));							
			
		}

		if( e.getType()==EventType.COMPUTATION_FINISHED ||
				e.getType()==EventType.COMPUTATION_CANCELLED) {
			resetProgressBar();
		}
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Private Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * 
	 */
	private void resetProgressBar(){
		bar.setMaximum(100);
		bar.setValue(0);
		bar.setString("0%\r");
		label.setText(messages.getString(GuiMessages.READY_FOR_COMPUTATION_LABEL_KEY));
	}

}
