/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
*/

package de.uni_due.inf.ti.raven.gui;

import javax.swing.table.DefaultTableModel;

import de.uni_due.inf.ti.raven.actions.RenameAction;
import de.uni_due.inf.ti.raven.data.Data;
import de.uni_due.inf.ti.raven.data.Repository;

/**
 * This is an implementation of {@code TableModel} that is used to display and 
 * rename the {@code Data} objects contained in the Raven repository. 
 * @author Christoph Blume, Laura Steinert
 * @version $Revision: 1.12 $
 *
 * @see Data
 * @see Repository
 */
public class RepositoryTableModel extends DefaultTableModel {

	private static final long serialVersionUID = 3021072146930716929L;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	@Override
	public boolean isCellEditable(int row, int column){		
		if (column == 0){
			return true;
		}

		return false;
	}

	@Override
	public void setValueAt(Object value, int row, int column) {
		if(value==null || !(value instanceof String)) {
			super.setValueAt(value, row, column);
		}
		
		String replacement = value.toString();
		if(replacement.isEmpty()) {
			Utilities.showErrorMessage(null, GuiMessages.EMPTY_NAME_TITLE_EXCEPTION_KEY, 
					GuiMessages.EMPTY_NAME_TEXT_EXCEPTION_KEY);
			return;
		}
		if(Repository.getRepository().contains(replacement) && 
				!replacement.equals(getValueAt(row, column).toString())) {
			Utilities.showErrorMessage(null, GuiMessages.NAME_ALREADY_IN_USE_TITLE_EXCEPTION_KEY,
					GuiMessages.NAME_ALREADY_IN_USE_TEXT_EXCEPTION_KEY, replacement);
			return;
		}
		
		String name = getValueAt(row, column).toString();
		RenameAction action = new RenameAction(name, replacement);
		action.execute();
	}

}
