/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.gui;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.FlowLayout;
import java.awt.Window;

import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextArea;

import de.uni_due.inf.ti.raven.main.RavenMain;

/**
 *
 * Displays version info and Raven logo in a RavenDialog.
 * @author Laura Steinert
 * @version $Revision: 1.8 $
 *
 */
public class ShowVersionDialog extends RavenDialog {

	private static final long serialVersionUID = 1951885057529987751L;

	private static ShowVersionDialog dialog;

	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	private ShowVersionDialog(Window owner) {
		super(owner, "Raven Version", RavenDialog.CLOSE_LAYOUT);
		JTextArea text = new JTextArea(RavenMain.getInfo());
		text.setEditable(false);
		
		ImageIcon icon = new ImageIcon(RavenMain.RAVEN_LOGO_FILENAME);		
		JLabel iconLabel = new JLabel(icon);
		
		JPanel flowPanel = new JPanel(new FlowLayout(FlowLayout.CENTER));
		flowPanel.add(text);
		flowPanel.setBackground(new Color(210, 200, 168));
		text.setBackground(flowPanel.getBackground());

		JPanel panel = new JPanel();
		panel.setLayout(new BorderLayout());
		panel.add(flowPanel, BorderLayout.CENTER);
		panel.add(iconLabel, BorderLayout.NORTH);
		
		setMainPane(panel);
		pack();
		setLocationRelativeTo(null); // centralize window
	}

	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Brings up the version dialog.
	 * @param owner the parent window of the dialog
	 */
	public static void showDialog(Window owner) {
		dialog = new ShowVersionDialog(owner);
		dialog.setVisible(true);
	}
}
