/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
*/

package de.uni_due.inf.ti.raven.gui;

import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JScrollPane;
import javax.swing.JTextField;
import javax.swing.ListCellRenderer;

import com.jgoodies.forms.builder.DefaultFormBuilder;
import com.jgoodies.forms.layout.FormLayout;

import de.uni_due.inf.ti.raven.data.Operation;
import de.uni_due.inf.ti.raven.data.Repository;
import de.uni_due.inf.ti.raven.data.Signature;

/**
 * This class provides a builder which is used to  create an {@code InformationPanel} 
 * for displaying information about <i>signatures</i>.
 * @author Christoph Blume
 * @version $Revision: 1.8 $
 *
 * @see Signature
 */
public final class SignatureInformationPanelBuilder extends InformationPanelBuilder<Signature> {

	/**
	 * 
	 * @author Christoph Blume
	 *
	 */
	private static class SignatureInformationPanel extends InformationPanel<Signature> {

		private static final long serialVersionUID = -7863466765014226310L;

		private Repository repo = Repository.getRepository();
		
		/*------------------------------------------------------------------------------------------*/
		/*		Public Methods																		*/
		/*------------------------------------------------------------------------------------------*/

		@Override
		public void setData(Signature signature) {
			signatureNameField.setText(repo.getName(signature));
			
			operationList.setListData(signature.getOperations().toArray(new Operation[0]));
		}
		
	}
	
	private static SignatureInformationPanelBuilder panelBuilder;
	private static InformationPanel<Signature> panel;
	private static JTextField signatureNameField;
	private static JList<Operation> operationList;

	/*------------------------------------------------------------------------------------------*/
	/* 		Static Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates an information panel displaying properties of a given signature.
	 * @return the signature information panel
	 */
	public static InformationPanel<Signature> createPanel() {
		if(panelBuilder==null) {
			panel = new SignatureInformationPanel();
			DefaultFormBuilder formBuilder = new DefaultFormBuilder(
					new FormLayout(LAYOUT_SPECIFICATION), panel);
			panelBuilder = new SignatureInformationPanelBuilder(formBuilder);
		}
	
		return panel;
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates the panel on which signature information will be displayed.
	 * @param formBuilder the form builder used to build the panel
	 */
	private SignatureInformationPanelBuilder(DefaultFormBuilder formBuilder) {
		super(formBuilder);
		formBuilder.getPanel().setOpaque(false);

		signatureNameField = new JTextField(10);
		signatureNameField.setEditable(false);
		signatureNameField.setOpaque(false);
		append(GuiMessages.NAME_LABEL_KEY, signatureNameField);

		appendSeparator();
		
		JScrollPane scrollPane = new JScrollPane();
		append(GuiMessages.OPERATIONS_LABEL_KEY, scrollPane);
		scrollPane.getViewport().setOpaque(false);
		scrollPane.setOpaque(false);
		
		operationList = new JList<>();
		operationList.setVisibleRowCount(8);
		operationList.setOpaque(false);
		operationList.setCellRenderer(new ListCellRenderer<Operation>() {

			@Override
			public JLabel getListCellRendererComponent(
					JList<? extends Operation> list, Operation value, int index,
					boolean isSelected, boolean cellHasFocus) {
				return new JLabel(value.toString());
			}
		});
		scrollPane.setViewportView(operationList);
	}

}
