/*
 * Copyright (c) 2009-
, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.gui;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.SplashScreen;

/**
 * This class is used to present the Raven splash screen while initializing the software.
 * @author Christoph Blume
 * @version $Revision: 1.7 $
 *
 */
public class SplashScreenWithProgressBar extends Thread {

	private final SplashScreen splashScreen;

	private Graphics2D g;

	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates a new splash-screen which shows a progress bar at the bottom of the screen.
	 * @param splashScreen the splash-screen to be used
	 */
	public SplashScreenWithProgressBar(SplashScreen splashScreen) {
		this.splashScreen = splashScreen;
		this.g = this.splashScreen.createGraphics();
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	@Override
	public void run(){
		int i=1;
		while(splashScreen.isVisible()){
			try {
				Thread.sleep(20);
			} catch (InterruptedException e) {
				// fail silently
			}
			if (i<50){
				i++;
				try {
					update(i / (float) 50);
				}
				catch (IllegalStateException e){
					// fail silently
				};
			}
		}
	}

	/**
	 * Fills the progress bar with a rectangle which's size corresponds to 'progress'.
	 * @param progress float between 0 and 1
	 */
	public void update(float progress) {
		if (progress < 0 || progress > 1 ){
			return;
		}
		
		Rectangle splashBounds = splashScreen.getBounds();
		int progressBarHeight = g.getFontMetrics().getHeight();
		int progressBarWidth = (int) (splashBounds.width * progress);
		int progressBarStartYPos = splashBounds.height - progressBarHeight;

		g.setColor(Color.DARK_GRAY);
		g.fillRect(0, progressBarStartYPos, progressBarWidth, progressBarHeight);

		this.splashScreen.update();
	}

}
