/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
*/

package de.uni_due.inf.ti.raven.gui;

import javax.swing.JTextField;

import com.jgoodies.forms.builder.DefaultFormBuilder;
import com.jgoodies.forms.layout.FormLayout;

import de.uni_due.inf.ti.raven.data.Repository;
import de.uni_due.inf.ti.raven.data.TreeDecomposition;

/**
 * This class provides a builder which is used to  create an {@code InformationPanel} 
 * for displaying information about <i>tree decompositions</i>.
 * @author Christoph Blume, Laura Steinert
 * @version $Revision: 1.5 $
 *
 * @see TreeDecomposition
 */
public final class TreeDecompositionInformationPanelBuilder extends InformationPanelBuilder<TreeDecomposition> {

	/**
	 * 
	 * @author Christoph Blume
	 *
	 */
	private static class TreeDecompositionInformationPanel extends InformationPanel<TreeDecomposition> {

		private static final long serialVersionUID = -1917528179482401656L;

		private static final Repository repo = Repository.getRepository();
		
		/*------------------------------------------------------------------------------------------*/
		/* 		Public Methods																		*/
		/*------------------------------------------------------------------------------------------*/

		@Override
		public void setData(TreeDecomposition decomp) {
			decompNameField.setText(repo.getName(decomp));
			
//			DefaultListModel<Operation> model = (DefaultListModel<Operation>) operationList.getModel();
//			model.clear();
//			for(Operation operation: decomp.getOperations()) {
//				model.addElement(operation);
//			}
		}
		
	}

	private static TreeDecompositionInformationPanelBuilder panelBuilder;
	private static InformationPanel<TreeDecomposition> panel;
	private static JTextField decompNameField;

	/*------------------------------------------------------------------------------------------*/
	/*		Static Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates an information panel displaying properties of a given tree decomposition.
	 * @return the tree decomposition information panel
	 */
	public static InformationPanel<TreeDecomposition> createPanel() {
		if(panelBuilder==null) {
			panel = new TreeDecompositionInformationPanel();
			DefaultFormBuilder builder = new DefaultFormBuilder(
					new FormLayout(LAYOUT_SPECIFICATION), panel);
			panelBuilder = new TreeDecompositionInformationPanelBuilder(builder);
		}
		
		return panel;
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/

	/**
	 * Creates the panel on which graph information will be displayed.
	 * @param formBuilder the form builder used to build the panel
	 */
	public TreeDecompositionInformationPanelBuilder(DefaultFormBuilder formBuilder) {
		super(formBuilder);
		formBuilder.getPanel().setOpaque(false);

		decompNameField = new JTextField();
		decompNameField.setEditable(false);
		decompNameField.setColumns(10);
		decompNameField.setOpaque(false);
		formBuilder.append(GuiMessages.NAME_LABEL_KEY, decompNameField);
	}

}
