/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.gui.actions;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JPopupMenu;

import de.uni_due.inf.ti.raven.gui.GuiMessages;
import de.uni_due.inf.ti.raven.gui.MainWindow;
import de.uni_due.inf.ti.raven.main.RavenMain;

/**
 * Brings up a popup menu to create and add data to the repository.
 * @author Christoph Blume
 * @version $Revision: 1.8 $
 *
 */
public final class AddToRepositoryAction extends AbstractAction {

	private static final long serialVersionUID = -5469771482246910950L;
	
	private MainWindow owner;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates an {@code Action} for the addition of data to the repository.
	 * @param owner the parent window of the action
	 * 
	 */
	public AddToRepositoryAction(MainWindow owner) {
//		putValue( Action.NAME, messages.getString(GuiMessages.REMOVE_FROM_REPOSITORY_LABEL_KEY));
//		putValue( Action.DISPLAYED_MNEMONIC_INDEX_KEY, 1 );
//		putValue( Action.ACCELERATOR_KEY, KeyStroke.getKeyStroke('Q', InputEvent.CTRL_DOWN_MASK));
		putValue( Action.SMALL_ICON, new ImageIcon(RavenMain.PLUS_ICON_FILENAME));
		putValue( Action.SHORT_DESCRIPTION, GuiMessages.getMessages().getString(GuiMessages.ADD_TO_REPOSITORY_LABEL_KEY));
				
		this.owner = owner;
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	@Override
	public void actionPerformed(ActionEvent e) {
		JButton button = (JButton) e.getSource();
		int x = button.getX()+button.getWidth()/2;
		int y = button.getY()+button.getHeight()/2;

		JPopupMenu popupMenu = new JPopupMenu();
		popupMenu.add(new CreateAutomatonAction(owner));
		popupMenu.add(new CreateCospanAction(owner));
		popupMenu.add(new CreateDecompositionAction(owner));
		popupMenu.add(new CreateGraphAction(owner));
		popupMenu.add(new CreateSignatureAction(owner));
		popupMenu.show(button, x, y);
	}

}
