/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.gui.actions;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.ImageIcon;
import javax.swing.JTable;

import de.uni_due.inf.ti.raven.actions.RemoveAction;
import de.uni_due.inf.ti.raven.data.Data;
import de.uni_due.inf.ti.raven.data.Repository;
import de.uni_due.inf.ti.raven.gui.GuiMessages;
import de.uni_due.inf.ti.raven.io.RavenPrinter;
import de.uni_due.inf.ti.raven.main.RavenMain;

/**
 * Handles the deletion of a {@code Data} object from the repository.
 * @author Christoph Blume
 * @version $Revision: 1.7 $
 *
 * @see Data
 * @see Repository
 */
public class RemoveFromRepositoryAction extends AbstractAction {

	private static final long serialVersionUID = 3909222278806932160L;
	
	private JTable table;
	private RavenPrinter printer;
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates an {@code Action} for the removal of data from the repository.
	 * @param table the table displaying repository information
	 * @param printer the printer to be used for the output of status information
	 * 
	 */
	public RemoveFromRepositoryAction(JTable table, RavenPrinter printer) {
//		putValue( Action.NAME, messages.getString(GuiMessages.REMOVE_FROM_REPOSITORY_LABEL_KEY));
//		putValue( Action.DISPLAYED_MNEMONIC_INDEX_KEY, 1 );
//		putValue( Action.ACCELERATOR_KEY, KeyStroke.getKeyStroke('Q', InputEvent.CTRL_DOWN_MASK));
		putValue( Action.SMALL_ICON, new ImageIcon(RavenMain.MINUS_ICON_FILENAME));
		putValue( Action.SHORT_DESCRIPTION, GuiMessages.getMessages().getString(GuiMessages.REMOVE_FROM_REPOSITORY_LABEL_KEY));
		
		this.table = table;
		this.printer = printer;
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	@Override
	public void actionPerformed(ActionEvent e) {
		int selectedRow = table.getSelectedRow();
		
		if(selectedRow>=0) {
			String name = table.getValueAt(selectedRow, 0).toString();
			
			RemoveAction action = new RemoveAction(name);
			action.execute();
			if(action.getResult()) {
				printer.println(GuiMessages.getMessages().getString(
						GuiMessages.DATA_REMOVED_MESSAGE_KEY, name));
			}
		}
	}

}
