/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.gui.actions;

import java.awt.Window;
import java.awt.event.ActionEvent;
import java.io.FileNotFoundException;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.JFileChooser;
import javax.swing.SwingUtilities;
import javax.swing.filechooser.FileFilter;

import de.uni_due.inf.ti.raven.cli.Console;
import de.uni_due.inf.ti.raven.gui.GuiMessages;
import de.uni_due.inf.ti.raven.gui.RavenFileFilter;
import de.uni_due.inf.ti.raven.gui.Utilities;
import de.uni_due.inf.ti.raven.io.RavenPrinter;
import de.uni_due.inf.ti.raven.main.RavenMain;

/**
 * Brings up a dialog to load a Raven script file.
 * @author Christoph Blume
 * @version $Revision: 1.8 $
 *
 */
public class RunScriptAction extends AbstractAction {

	private static final long serialVersionUID = 6665334121165112370L;

	private static GuiMessages messages = GuiMessages.getMessages();

	private Window owner;
	private RavenPrinter printer;

	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/

	/**
	 * Creates an {@code Action} for the run Raven scripts.
	 * @param owner the parent window of the action
	 * @param printer the printer to be used for the output of status information
	 * 
	 */
	public RunScriptAction(Window owner, RavenPrinter printer) {
		putValue( Action.NAME, messages.getString("raven.label.runScript"));
//		putValue( Action.DISPLAYED_MNEMONIC_INDEX_KEY, 1 );
//		putValue( Action.ACCELERATOR_KEY, KeyStroke.getKeyStroke('Q', InputEvent.CTRL_DOWN_MASK));
//		putValue( Action.SMALL_ICON, new ImageIcon(RavenMain.ICON_DIR + "16x16/actions/list-add.png"));

		this.owner = owner;
		this.printer = printer;
	}

	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/

	@Override
	public void actionPerformed(ActionEvent e) {
		JFileChooser fc = new JFileChooser(RavenMain.SCRIPT_DIR);
		FileFilter filter = RavenFileFilter.RAVEN_SCRIPT_FILE_FILTER;
		fc.setFileFilter(filter);

		int value = fc.showOpenDialog(owner);
		if(value==JFileChooser.APPROVE_OPTION) {
			final String filename = fc.getSelectedFile().getAbsolutePath();

			//Start new thread to run selected batch file
			SwingUtilities.invokeLater(new Runnable() {

				@Override
				public void run() {
					try {
						Console.runBatchFile(filename, printer);
					} catch (FileNotFoundException ex) {
						Utilities.showErrorMessage(owner, 
								GuiMessages.FILE_NOT_FOUND_TITLE_EXCEPTION_KEY, 
								GuiMessages.FILE_NOT_FOUND_TEXT_EXCEPTION_KEY, filename);
					}
				}
			});
		}
	}

}
