/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
*/

package de.uni_due.inf.ti.raven.gui.automaton;

import javax.swing.JTextField;

import de.uni_due.inf.ti.raven.data.automata.VertexCountingAutomaton;
import de.uni_due.inf.ti.raven.gui.GuiMessages;
import de.uni_due.inf.ti.raven.gui.InformationPanel;

/**
 * This class provides an {@code InformationPanel} for displaying information about vertex-counting
 * graph automata.
 * @author Christoph Blume
 * @version $Revision: 1.5 $
 *
 * @see AutomatonInformationPanelBuilder
 * @see VertexCountingAutomaton
 */
public final class VertexCountingAutomatonInformationPanelBuilder extends AutomatonInformationPanelBuilder {
	
	/**
	 * 
	 * @author Christoph Blume
	 *
	 */
	private static class VertexCountingAutomatonInformationPanel extends AutomatonInformationPanel<VertexCountingAutomaton> {

		private static final long serialVersionUID = -3267332555302461823L;
		
		/*------------------------------------------------------------------------------------------*/
		/* 		Public Methods																		*/
		/*------------------------------------------------------------------------------------------*/
		
		@Override
		public void setAdditionalData(final VertexCountingAutomaton automaton) {
			// Fill-in vertex-counting automaton specific informations
			divisorField.setText(String.valueOf(automaton.getDivisor()));
			remainderField.setText(String.valueOf(automaton.getRemainder()));
		}
		
	}

	/** Divisor Text Field Label (used for Testing) */
	protected static final String DIVISOR_LABEL = "divisor";
	
	/** Remainder Text Field Label (used for Testing) */
	protected static final String REMAINDER_LABEL = "remainder";

	private static VertexCountingAutomatonInformationPanelBuilder panelBuilder;
	private static AutomatonInformationPanel<VertexCountingAutomaton> panel;
	private static JTextField divisorField;
	private static JTextField remainderField;

	/*------------------------------------------------------------------------------------------*/
	/* 		Static Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates an information panel displaying properties of a given vertex-counting automaton.
	 * @return the vertex-counting automaton information panel
	 */
	public static InformationPanel<VertexCountingAutomaton> createPanel() {
		if(panelBuilder==null) {
			panel = new VertexCountingAutomatonInformationPanel();
			panelBuilder = new VertexCountingAutomatonInformationPanelBuilder(panel);
		}
	
		return panel;
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates the panel on which automaton information will be displayed.
	 * @param panel the form builder used to build the panel
	 */
	private VertexCountingAutomatonInformationPanelBuilder(
			AutomatonInformationPanel<VertexCountingAutomaton> panel) {
		super(panel);
	}

	@Override
	protected void addAdditionalComponents() {
		divisorField = new JTextField(10);
		divisorField.setName(DIVISOR_LABEL);
		divisorField.setEditable(false);
		divisorField.setOpaque(false);
		append(GuiMessages.DIVISOR_LABEL_KEY, divisorField);
		
		remainderField = new JTextField(10);
		remainderField.setName(REMAINDER_LABEL);
		remainderField.setEditable(false);
		remainderField.setOpaque(false);
		append(GuiMessages.REMAINDER_EDGES_LABEL_KEY, remainderField);

	}
	
}
