/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
*/

package de.uni_due.inf.ti.raven.gui.automaton;

import javax.swing.JTextField;

import de.uni_due.inf.ti.raven.data.automata.VertexCoverAutomaton;
import de.uni_due.inf.ti.raven.gui.GuiMessages;
import de.uni_due.inf.ti.raven.gui.InformationPanel;

/**
 * This class provides an {@code InformationPanel} for displaying information about vertex cover
 * graph automata.
 * @author Christoph Blume
 * @version $Revision: 1.5 $
 *
 * @see AutomatonInformationPanelBuilder
 * @see VertexCoverAutomaton
 */
public final class VertexCoverAutomatonInformationPanelBuilder extends AutomatonInformationPanelBuilder {
	
	/**
	 * 
	 * @author Christoph Blume
	 *
	 */
	private static class VertexCoverAutomatonInformationPanel extends AutomatonInformationPanel<VertexCoverAutomaton> {

		private static final long serialVersionUID = -3267332555302461823L;
		
		/*------------------------------------------------------------------------------------------*/
		/* 		Public Methods																		*/
		/*------------------------------------------------------------------------------------------*/
		
		@Override
		public void setAdditionalData(final VertexCoverAutomaton automaton) {
			// Fill-in vertex-cover automaton specific informations
			maximumVertexCoverSizeField.setText(String.valueOf(automaton.getMaximumVertexCoverSize()));
		}
		
	}

	/** Maximum Vertex Cover Size Text Field Label (used for Testing) */
	protected static final String MAXIMUM_VERTEX_COVER_SIZE_LABEL = "maximumVertexCoverSize";

	private static VertexCoverAutomatonInformationPanelBuilder panelBuilder;
	private static AutomatonInformationPanel<VertexCoverAutomaton> panel;
	private static JTextField maximumVertexCoverSizeField;

	/*------------------------------------------------------------------------------------------*/
	/* 		Static Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates an information panel displaying properties of a given vertex cover automaton.
	 * @return the vertex cover automaton information panel
	 */
	public static InformationPanel<VertexCoverAutomaton> createPanel() {
		if(panelBuilder==null) {
			panel = new VertexCoverAutomatonInformationPanel();
			panelBuilder = new VertexCoverAutomatonInformationPanelBuilder(panel);
		}
	
		return panel;
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates the panel on which automaton information will be displayed.
	 * @param panel the form builder used to build the panel
	 */
	private VertexCoverAutomatonInformationPanelBuilder(
			AutomatonInformationPanel<VertexCoverAutomaton> panel) {
		super(panel);
	}

	@Override
	protected void addAdditionalComponents() {
		maximumVertexCoverSizeField = new JTextField(10);
		maximumVertexCoverSizeField.setName(MAXIMUM_VERTEX_COVER_SIZE_LABEL);
		maximumVertexCoverSizeField.setEditable(false);
		maximumVertexCoverSizeField.setOpaque(false);
		append(GuiMessages.MAXIMUM_VERTEX_COVER_SIZE_LABEL_KEY, maximumVertexCoverSizeField);

	}
	
}
