/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.gui.graphs;

import com.mxgraph.model.mxCell;

import de.uni_due.inf.ti.raven.encodings.BDDEncoding;
import de.uni_due.inf.ti.raven.encodings.BDDEncoding.StateType;
import de.uni_due.inf.ti.raven.encodings.NoIsolatedNodesEncoding;
import de.uni_due.inf.ti.raven.gui.GuiMessages;
import de.uni_due.inf.ti.raven.gui.graphs.EncodingView.EncodingVisualizer;

/**
 * This class provides a {@code Display} to visualize <i>NoIsolatedNodes encodings</i>.
 * @author Christoph Blume, Dennis Nolte
 * @version $Revision: 1.5 $
 *
 * @see BDDEncoding
 */
public class NoIsolatedNodesEncodingVisualizer extends EncodingVisualizer<NoIsolatedNodesEncoding> {
	
	/*------------------------------------------------------------------------------------------*/
	/*		Protected Methods 																	*/
	/*------------------------------------------------------------------------------------------*/

	@Override
	protected void visualizeStateBits(StateType type, NoIsolatedNodesEncoding encoding) {
		visualGraph.getModel().beginUpdate();
		try {
			int offset = getOffset(encoding, type);
			int interfaceLength = encoding.getInterfaceLength();
			leftShift = interfaceLength % 2 == 0 ? 1 : 0;
			int groupPos = interfaceLength/2;
			
			Object[] interfaceNodes = new Object[interfaceLength];
			for(int i=0; i<interfaceLength;i++) {
				interfaceNodes[i] = addInterfaceVertex(type, i, String.valueOf(offset+i*2));
				addBitLabel(type, i, String.valueOf(i));
				if(i == groupPos) {
					addGroupLabel(type, i,GuiMessages.getMessages().getString(
							GuiMessages.INTERFACE_BITS_LABEL_KEY));
				}
			}
			mxCell group = (mxCell) visualGraph.groupCells(null, 5, interfaceNodes);
			group.setStyle(VisualGraph.INTERFACE_WHITE_BACKGROUND_STYLE);
			
			int encodingIsolateLength = encoding.getLength()-interfaceLength-1;
			leftShift = encodingIsolateLength % 2 == 0 ? 1 : 0;
			groupPos = encodingIsolateLength/2;
			
			Object[] encodingIsolateNodes = new Object[encodingIsolateLength];
			for(int i=interfaceLength;i<interfaceLength+encodingIsolateLength;i++) {
				
				encodingIsolateNodes[i-interfaceLength] = addStateVertex(type, i, String.valueOf(offset+i*2));
				addBitLabel(type, i, String.valueOf(i));
				addIsolateBitLabel(type, i, String.valueOf((i-interfaceLength)));
				if((i-interfaceLength) == groupPos) {
					addGroupLabel(type, i, messages.getString(GuiMessages.ISOLATION_BITS_LABEL_KEY));
				}	
			}
			group = (mxCell) visualGraph.groupCells(null, 5, encodingIsolateNodes);
			group.setStyle(VisualGraph.COLOR_STYLE[VisualGraph.YELLOW]);
			
			Object[] encodingIsIsolatedFlagNode = new Object[1];
			int pos = interfaceLength+encodingIsolateLength;
			leftShift = 0;	
			
			encodingIsIsolatedFlagNode[0] = addStateVertex(type, pos, String.valueOf(offset+pos*2));
			addBitLabel(type, pos, String.valueOf(pos));
			addGroupLabel(type, pos, messages.getString(GuiMessages.ISOLATION_FLAG_LABEL_KEY));	
			
			group = (mxCell) visualGraph.groupCells(null, 5, encodingIsIsolatedFlagNode);
			group.setStyle(VisualGraph.INTERFACE_WHITE_BACKGROUND_STYLE);
			
			
		}
		finally{
			visualGraph.getModel().endUpdate();
		}
	}

	/*------------------------------------------------------------------------------------------*/
	/*		Private Methods 																	*/
	/*------------------------------------------------------------------------------------------*/
	
	private mxCell addIsolateBitLabel(StateType type, int number, String label) {
		int row = type==StateType.current ? 0 : 1;
		Object parent = visualGraph.getDefaultParent();
		int x = X_OFFSET + number*X_MARGIN;
		int y = Y_OFFSET + row*Y_MARGIN+Y_MARGIN/5 + GAP_CONSTANT;
		
		return (mxCell) visualGraph.insertVertex(parent, null, 
				messages.getString(GuiMessages.ISOLATION_BIT_LABEL_KEY, label), x, y, 
				INTERFACE_VERTEX_SIZE, INTERFACE_VERTEX_SIZE, VisualGraph.LABEL_STYLE);
	}

}