/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.io;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.util.logging.Logger;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;

import de.uni_due.inf.ti.raven.data.automata.Automaton;
import de.uni_due.inf.ti.raven.messages.Messages;

/**
 * This class provides operations for reading automata from files.
 * @author Christoph Blume, Laura Steinert
 * @version $Revision: 1.11 $
 *
 */
public class AutomatonFileReader implements AutomatonReader {

	private static Logger logger = Logger.getLogger(Messages.class.getName());
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/

	@Override
	public Automaton readAutomaton(String filename) 
			throws FileNotFoundException, IOException {
		Automaton automaton = null;
		
		//Deserialize the automaton
		try(ZipFile zipFile = new ZipFile(filename)) {
			ZipEntry general = zipFile.getEntry(Automaton.AUTOMATON_MAIN_FILE);
			try(ObjectInputStream o = new ObjectInputStream(
					zipFile.getInputStream(general))) {
				automaton = (Automaton) o.readObject();				
				automaton.initializeEncoding();
				// restore the rest of the automaton (bdds)
				automaton.readAutomatonFromZip(filename);
			}
			catch (ClassNotFoundException e) {
				logger.throwing(getClass().getName(), "readAutomaton", e);
			};
			
		};
		return automaton;	
	}

}
