/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.io;

import java.io.FileNotFoundException;
import java.io.IOException;

import de.uni_due.inf.ti.raven.data.automata.Automaton;
import de.uni_due.inf.ti.raven.main.RavenMain;

/**
 * This class provides operations for writing automata to files.
 * @author Laura Steinert
 * @version $Revision: 1.1 $
 *
 */
public class AutomatonFileWriter implements AutomatonWriter{
	
	private static AutomatonFileWriter writer;

	/*------------------------------------------------------------------------------------------*/
	/*		Public Static Methods																*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Returns a {@code DataObjectFileWriter} to save {@code Data} objects to files.
	 * @return the file writer
	 */
	public static AutomatonFileWriter getWriter() {
		if(writer==null) {
			writer = new AutomatonFileWriter();
		}
		
		return writer;
	}

	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Writes an automaton to the zip archive specified by {@code zipname}.
	 * @param automaton the automaton to be written
	 * @param zipname the name of the zip archive to which the automaton is written
	 * @throws FileNotFoundException thrown  if the file exists but is a directory rather than a 
	 * regular file, does not exist but cannot be created, or cannot be opened for any other reason
	 * @throws IOException thrown if an I/O error occurs while writing the automaton
	 */
	@Override
	public void write(Automaton automaton, String zipname) 
			throws FileNotFoundException, IOException{
		if (!zipname.endsWith("."+RavenMain.AUTOMATON_FILE_EXTENSION)){
			zipname = zipname + "." + RavenMain.AUTOMATON_FILE_EXTENSION;
		}
		automaton.writeAutomatonToZip(zipname);
	}

}
