/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.io;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

import de.uni_due.inf.ti.raven.data.Operation;
import de.uni_due.inf.ti.raven.data.Signature;

/**
 * This class provides operation for reading signatures from files.
 * @author Christoph Blume, Laura Steinert
 * @version $Revision: 1.6 $
 *
 */
public class SignatureFileReader {

	/*------------------------------------------------------------------------------------------*/
	/*		Public Static Methods																*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Reads a signature from the file given by the filename {@code filename}.
	 * @param filename the filename from which the signature is red
	 * @return the signature read from the given file
	 * @throws FileNotFoundException thrown if the file indicated by the filename does not exist
	 * @throws IOException thrown if an I/O exception occurred during reading the given file
	 */
	public static Signature read(String filename) throws FileNotFoundException, IOException {
		Signature sig = new Signature();
		try (BufferedReader reader = new BufferedReader(new FileReader(filename))) {
			String line;
			while((line = reader.readLine())!=null) {
				line = line.trim();
				
				if(!line.isEmpty()) {
					sig.add(Operation.parse(line));
				}
			}
		}

		return sig;
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	private SignatureFileReader() {}
	
}
