/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.main;

import java.io.OutputStream;
import java.util.logging.Formatter;
import java.util.logging.LogRecord;
import java.util.logging.StreamHandler;

/**
 * This class provides a logging handler for Raven which is intended to log all 
 * Raven events to a specified {@code OutputStream}. In most cases this handler 
 * will be used to log the events to a log file.
 * @author Christoph Blume
 * @version $Revision: 1.9 $
 *
 */
public class RavenLoggingHandler extends StreamHandler {

	/*------------------------------------------------------------------------------------------*/
	/*		Constructors																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Creates a new logging handler which uses the default system output stream and a default formatter.
	 */
	public RavenLoggingHandler() {
		this(System.out);
	}
	
	/**
	 * Creates a new logging handler which uses output stream {@code out} and a default formatter.
	 * @param out the output stream to be used
	 */
	public RavenLoggingHandler(OutputStream out) {
		this(out, new Formatter() {
			
			@Override
			public String format(LogRecord record) {
				return record.getMessage() + System.getProperty("line.separator");
			}
		});
	}
	
	/**
	 * /**
	 * Creates a new logging handler which uses output stream {@code out} and the formatter 
	 * {@code formatter}.
	 * @param out the output stream to be used
	 * @param formatter the formatter to be used
	 */
	public RavenLoggingHandler(OutputStream out, Formatter formatter) {
		super(out, formatter);
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	
	@Override
	public void publish(LogRecord record) {
		super.publish(record);
		flush();
	}
	
}
