/*
 * Copyright (c) 2009-2014, Christoph Blume
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 * 3. Neither the name of the "Theoretical Computer Science, University of
 * Duisburg-Essen, Germany" nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.uni_due.inf.ti.raven.messages;

import java.util.MissingResourceException;
import java.util.ResourceBundle;
import java.util.logging.Logger;

/**
 * This class is the base class for the resource bundle-based message system.
 * @author Christoph Blume
 * @version $Revision: 1.14 $
 *
 */
public abstract class Messages {
	
	private static Logger logger = Logger.getLogger(Messages.class.getName());
	
	private final ResourceBundle RESOURCE_BUNDLE;
	
	/**
	 * Creates a new message bundle depending on the resource bundle named {@code resourceBundleName}.
	 * @param resourceBundleName the name of the underlying resource bundle
	 */
	protected Messages(String resourceBundleName) {
		RESOURCE_BUNDLE = ResourceBundle.getBundle(resourceBundleName);		
	}
	
	/*------------------------------------------------------------------------------------------*/
	/*		Public Methods																		*/
	/*------------------------------------------------------------------------------------------*/
	
	/**
	 * Returns the console-message string for the given key.
	 * @param key the key for the requested console-message
	 * @param param strings by which the variable place-holders "%1", "%2", etc, 
	 * are to be replaced
	 * @return the requested console-message
	 * 
	 * @see #getString(String)
	 */
	public String getString(String key, String... param) {
		if(key==null || key.isEmpty()) {
			return key;
		}
		
		String text = null;

		try {
			text = RESOURCE_BUNDLE.getString(key);
			text = CommandTextInfo.getCommandTextInfo(text, param).getText();
			return text.trim();
		} catch (MissingResourceException e) {
			logger.warning("Key '"+key+"' not found.");
			return key;
		}
	}
	
	/**
	 * Returns the console-message string for the given key.
	 * @param key the key for the requested console-message
	 * @return the requested console-message
	 * 
	 * @see #getString(String, String...)
	 */
	public String getString(String key) {
		return getString(key, new String[0]);
	}
	
}
